@@ -5,14 +5,12 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: dfanf.c 6357 2016-05-13 05:00:06Z bmribler $ */
-
 /*-----------------------------------------------------------------------------
  * File:    dfanF.c
  * Purpose: Fortran stubs for annotation routines
@@ -45,24 +43,24 @@
 #include "hproto_fortran.h"
 
 /* conventions used in forming names of routines:
-   **
-   **    dfan: hdf annotation routine (<dfan>addfds)
-   **    add:  add item to file       dfan<add>fds
-   **    get:  get item from file     dfan<get>fds
-   **    f:    file                   dfanadd<f>ds
-   **    id:   id                     dfanaddf<id>
-   **    ds:   description            dfanaddf<ds>
-   **    len:  length                 dfanaddfid<len>
-   **    l:    length (short forms)   dagfid<l>
-   **    da:   dfan (short forms)     <da>gfid
-   **    a:    add (short forms)      da<a>fds
-   **    g:    get (short forms)      da<g>fds
-   **    i:    intermediate routine (not in user interface) da<i>afid
-   * */
+ **
+ **    dfan: hdf annotation routine (<dfan>addfds)
+ **    add:  add item to file       dfan<add>fds
+ **    get:  get item from file     dfan<get>fds
+ **    f:    file                   dfanadd<f>ds
+ **    id:   id                     dfanaddf<id>
+ **    ds:   description            dfanaddf<ds>
+ **    len:  length                 dfanaddfid<len>
+ **    l:    length (short forms)   dagfid<l>
+ **    da:   dfan (short forms)     <da>gfid
+ **    a:    add (short forms)      da<a>fds
+ **    g:    get (short forms)      da<g>fds
+ **    i:    intermediate routine (not in user interface) da<i>afid
+ * */
 
 /*---------------------------------------------------------------------------
 ** Routines for handling tag/ref (not file) annotations
- *-------------------------------------------------------------------------*/
+*-------------------------------------------------------------------------*/
 /*---------------------------------------------------------------------------
  * Name:    daclear
  * Purpose: Call DFANIclear to clear Lastref and DFANdir[i]
@@ -75,7 +73,7 @@
 FRETVAL(intf)
 ndaclear(void)
 {
-    return(DFANIclear());
+    return (DFANIclear());
 }
 
 /*-----------------------------------------------------------------------------
@@ -91,16 +89,16 @@ ndaclear(void)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndaiganl(_fcd filename, intf * tag, intf * ref, intf * type, intf * fnlen)
+ndaiganl(_fcd filename, intf *tag, intf *ref, intf *type, intf *fnlen)
 {
-    char       *fn;
-    intf        ret;
+    char *fn;
+    intf  ret;
 
-    fn = HDf2cstring(filename, (intn) *fnlen);
+    fn = HDf2cstring(filename, (intn)*fnlen);
     if (!fn)
-	return(-1);
-    ret = DFANIgetannlen(fn, (uint16) *tag, (uint16) *ref, (intn) *type);
-    HDfree((VOIDP) fn);
+        return (-1);
+    ret = DFANIgetannlen(fn, (uint16)*tag, (uint16)*ref, (intn)*type);
+    free(fn);
 
     return (ret);
 }
@@ -120,18 +118,17 @@ ndaiganl(_fcd filename, intf * tag, intf * ref, intf * type, intf * fnlen)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndaigann(_fcd filename, intf * tag, intf * ref, _fcd annotation, intf * maxlen,
-         intf * type, intf * fnlen)
+ndaigann(_fcd filename, intf *tag, intf *ref, _fcd annotation, intf *maxlen, intf *type, intf *fnlen)
 {
-    char       *fn;
-    intf        ret;
+    char *fn;
+    intf  ret;
 
-    fn = HDf2cstring(filename, (intn) *fnlen);
+    fn = HDf2cstring(filename, (intn)*fnlen);
     if (!fn)
-	return(-1);
-    ret = DFANIgetann(fn, (uint16) *tag, (uint16) *ref,
-		      (uint8 *) _fcdtocp(annotation), (int32) *maxlen, (intn) *type, 1);
-    HDfree((VOIDP) fn);
+        return (-1);
+    ret = DFANIgetann(fn, (uint16)*tag, (uint16)*ref, (uint8 *)_fcdtocp(annotation), (int32)*maxlen,
+                      (intn)*type, 1);
+    free(fn);
 
     return (ret);
 }
@@ -151,18 +148,17 @@ ndaigann(_fcd filename, intf * tag, intf * ref, _fcd annotation, intf * maxlen,
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndaipann(_fcd filename, intf * tag, intf * ref, _fcd annotation,
-         intf * annlen, intf * type, intf * fnlen)
+ndaipann(_fcd filename, intf *tag, intf *ref, _fcd annotation, intf *annlen, intf *type, intf *fnlen)
 {
-    char       *fn;
-    intf        ret;
+    char *fn;
+    intf  ret;
 
-    fn = HDf2cstring(filename, (intn) *fnlen);
+    fn = HDf2cstring(filename, (intn)*fnlen);
     if (!fn)
-	return(-1);
-    ret = DFANIputann(fn, (uint16) *tag, (uint16) *ref,
-             (uint8 *) _fcdtocp(annotation), (int32) *annlen, (intn) *type);
-    HDfree((VOIDP) fn);
+        return (-1);
+    ret = DFANIputann(fn, (uint16)*tag, (uint16)*ref, (uint8 *)_fcdtocp(annotation), (int32)*annlen,
+                      (intn)*type);
+    free(fn);
     return (ret);
 }
 
@@ -175,7 +171,7 @@ ndaipann(_fcd filename, intf * tag, intf * ref, _fcd annotation,
  *          labellist: array of strings to place labels in
  *          listsize: size of ref and label lists
  *          maxlen: maximum length allowed for label
- *          startpos: beginning from the startpos'th entry, upto listsize
+ *          startpos: beginning from the startpos'th entry, up to listsize
  *              entries will be returned.
  *          fnlen: length of filename
  * Returns: number of entries on success, -1 on error with DFerror set
@@ -186,26 +182,25 @@ ndaipann(_fcd filename, intf * tag, intf * ref, _fcd annotation,
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndailist(_fcd filename, intf * tag, intf reflist[], _fcd labellist,
-         intf * listsize, intf * maxlen, intf * startpos, intf * fnlen)
+ndailist(_fcd filename, intf *tag, intf reflist[], _fcd labellist, intf *listsize, intf *maxlen,
+         intf *startpos, intf *fnlen)
 {
-    char       *fn;
-    int         i;
-    intf        nrefs;
-    uint16     *tempreflist;
+    char   *fn;
+    int     i;
+    intf    nrefs;
+    uint16 *tempreflist;
 
-    fn = HDf2cstring(filename, (intn) *fnlen);
+    fn = HDf2cstring(filename, (intn)*fnlen);
     if (!fn)
-	return(-1);
+        return (-1);
 
     /* create reflist with true uint16s to maintain compatibility
-       ** with machines that allocate more than 16 bits per uint16.
+     ** with machines that allocate more than 16 bits per uint16.
      */
-    tempreflist = (uint16 *) HDmalloc((size_t) (*listsize) * sizeof(uint16));
+    tempreflist = (uint16 *)malloc((size_t)(*listsize) * sizeof(uint16));
     /* 1 for isfortran */
-    nrefs = DFANIlablist(fn, (uint16) *tag, tempreflist,
-                         (uint8 *) _fcdtocp(labellist),
-                         (int) *listsize, (int) *maxlen, (int) *startpos, 1);
+    nrefs = DFANIlablist(fn, (uint16)*tag, tempreflist, (uint8 *)_fcdtocp(labellist), (int)*listsize,
+                         (int)*maxlen, (int)*startpos, 1);
     if (nrefs < 0)
         return FAIL;
 
@@ -213,8 +208,8 @@ ndailist(_fcd filename, intf * tag, intf reflist[], _fcd labellist,
     for (i = 0; i < *listsize; i++)
         reflist[i] = (intf)tempreflist[i];
 
-    HDfree((VOIDP) fn);
-    HDfree((VOIDP) tempreflist);
+    free(fn);
+    free(tempreflist);
 
     return (nrefs);
 }
@@ -255,7 +250,7 @@ ndfanlastref(void)
 
 /*---------------------------------------------------------------------------
 ** Routines for handling file annotations
- *-------------------------------------------------------------------------*/
+*-------------------------------------------------------------------------*/
 
 /*-----------------------------------------------------------------------------
  * Name:    dfanaddfds
@@ -269,7 +264,7 @@ ndfanlastref(void)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndfanaddfds(intf * dfile, _fcd desc, intf * desclen)
+ndfanaddfds(intf *dfile, _fcd desc, intf *desclen)
 {
     return (DFANIaddfann(*dfile, _fcdtocp(desc), *desclen, DFAN_DESC));
 }
@@ -285,9 +280,9 @@ ndfanaddfds(intf * dfile, _fcd desc, intf * desclen)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndfangetfidlen(intf * dfile, intf * isfirst)
+ndfangetfidlen(intf *dfile, intf *isfirst)
 {
-    return (DFANIgetfannlen(*dfile, DFAN_LABEL, (intn) *isfirst));
+    return (DFANIgetfannlen(*dfile, DFAN_LABEL, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -301,9 +296,9 @@ ndfangetfidlen(intf * dfile, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndfangetfdslen(intf * dfile, intf * isfirst)
+ndfangetfdslen(intf *dfile, intf *isfirst)
 {
-    return (DFANIgetfannlen(*dfile, DFAN_DESC, (intn) *isfirst));
+    return (DFANIgetfannlen(*dfile, DFAN_DESC, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -318,10 +313,9 @@ ndfangetfdslen(intf * dfile, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndfangetfid(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
+ndfangetfid(intf *dfile, _fcd id, intf *maxlen, intf *isfirst)
 {
-    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen,
-                         DFAN_LABEL, (intn) *isfirst));
+    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen, DFAN_LABEL, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -336,10 +330,9 @@ ndfangetfid(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndfangetfds(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
+ndfangetfds(intf *dfile, _fcd id, intf *maxlen, intf *isfirst)
 {
-    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen,
-                         DFAN_DESC, (intn) *isfirst));
+    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen, DFAN_DESC, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -358,7 +351,7 @@ ndfangetfds(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndaafds(intf * dfile, _fcd desc, intf * desclen)
+ndaafds(intf *dfile, _fcd desc, intf *desclen)
 {
     return (DFANIaddfann(*dfile, _fcdtocp(desc), *desclen, DFAN_DESC));
 }
@@ -374,9 +367,9 @@ ndaafds(intf * dfile, _fcd desc, intf * desclen)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndagfidl(intf * dfile, intf * isfirst)
+ndagfidl(intf *dfile, intf *isfirst)
 {
-    return (DFANIgetfannlen(*dfile, DFAN_LABEL, (intn) *isfirst));
+    return (DFANIgetfannlen(*dfile, DFAN_LABEL, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -390,9 +383,9 @@ ndagfidl(intf * dfile, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndagfdsl(intf * dfile, intf * isfirst)
+ndagfdsl(intf *dfile, intf *isfirst)
 {
-    return (DFANIgetfannlen(*dfile, DFAN_DESC, (intn) *isfirst));
+    return (DFANIgetfannlen(*dfile, DFAN_DESC, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -407,10 +400,9 @@ ndagfdsl(intf * dfile, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndagfid(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
+ndagfid(intf *dfile, _fcd id, intf *maxlen, intf *isfirst)
 {
-    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen,
-                         DFAN_LABEL, (intn) *isfirst));
+    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen, DFAN_LABEL, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -426,10 +418,9 @@ ndagfid(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndagfds(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
+ndagfds(intf *dfile, _fcd id, intf *maxlen, intf *isfirst)
 {
-    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen,
-                         DFAN_DESC, (intn) *isfirst));
+    return (DFANIgetfann(*dfile, _fcdtocp(id), *maxlen, DFAN_DESC, (intn)*isfirst));
 }
 
 /*-----------------------------------------------------------------------------
@@ -448,7 +439,7 @@ ndagfds(intf * dfile, _fcd id, intf * maxlen, intf * isfirst)
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
-ndaiafid(intf * dfile, _fcd id, intf * idlen)
+ndaiafid(intf *dfile, _fcd id, intf *idlen)
 {
     return (DFANIaddfann(*dfile, _fcdtocp(id), *idlen, DFAN_LABEL));
 }
