@@ -15,33 +15,31 @@
   Credits:
          Original code is part of the public domain 'Generic List Library'
          by Keith Pomakis(kppomaki@jeeves.uwaterloo.ca)-Spring, 1994
-         It has been modifed to adhere to HDF coding standards.
+         It has been modified to adhere to HDF coding standards.
 
   1996/05/29 - George V.
  ************************************************************************/
 
-/* $Id$ */
-
-#ifndef GLIST_H
-#define GLIST_H
+#ifndef H4_GLIST_H
+#define H4_GLIST_H
 
 #include "hdf.h" /* needed for data types */
 
 /* Structure for each element in the list */
 typedef struct GLE_struct {
-    VOIDP                pointer;   /* data element itself */
-    struct GLE_struct   *previous; /* previous element */
-    struct GLE_struct   *next;     /* next element */
+    void              *pointer;  /* data element itself */
+    struct GLE_struct *previous; /* previous element */
+    struct GLE_struct *next;     /* next element */
 } Generic_list_element;
 
 /* List info structure */
 typedef struct GLI_struct {
-    Generic_list_element   *current;               /* current element */
-    Generic_list_element   pre_element;            /* pre element */
-    Generic_list_element   post_element;           /* post element */
-    Generic_list_element   deleted_element;        /* deleted element */
-    intn                  (*lt)(VOIDP a, VOIDP b); /* sort fcn */
-    uint32                 num_of_elements;        /* number of elements */
+    Generic_list_element *current;         /* current element */
+    Generic_list_element  pre_element;     /* pre element */
+    Generic_list_element  post_element;    /* post element */
+    Generic_list_element  deleted_element; /* deleted element */
+    intn (*lt)(void *a, void *b);          /* sort fcn */
+    uint32 num_of_elements;                /* number of elements */
 } Generic_list_info;
 
 /* Top most List structure, handle to the list */
@@ -53,7 +51,7 @@ typedef struct GL_struct {
 #define Generic_stack Generic_list
 #define Generic_queue Generic_list
 
-/* Function declarations 
+/* Function declarations
    Descriptions for the General List routines can be found in 'glist.c'
    while the stack and queue routines are found below
  */
@@ -89,10 +87,10 @@ intn HDGLinitialize_list(Generic_list *list /* IN: list */);
     less-than function.  The only time it is valid to re-initialize a list
     is after it has been destroyed.
  RETURNS
-     SUCEED/FAIL
+     SUCCEED/FAIL
 *******************************************************************************/
-intn HDGLinitialize_sorted_list(Generic_list *list/*IN: list */, 
-                                intn (*lt)(VOIDP a, VOIDP b)/*IN:sort fcn */);
+intn HDGLinitialize_sorted_list(Generic_list *list /*IN: list */,
+                                intn (*lt)(void *a, void *b) /*IN:sort fcn */);
 
 /******************************************************************************
  NAME
@@ -121,7 +119,7 @@ void HDGLdestroy_list(Generic_list *list /*IN: list */);
     SUCCEED/FAIL
 *******************************************************************************/
 intn HDGLadd_to_beginning(Generic_list list, /*IN: list */
-                          VOIDP pointer /*IN: data element */ );
+                          void        *pointer /*IN: data element */);
 
 /******************************************************************************
  NAME
@@ -133,7 +131,7 @@ intn HDGLadd_to_beginning(Generic_list list, /*IN: list */
     SUCCEED/FAIL
 *******************************************************************************/
 intn HDGLadd_to_end(Generic_list list, /*IN: list */
-                    VOIDP pointer /*IN: data element */);
+                    void        *pointer /*IN: data element */);
 
 /******************************************************************************
  NAME
@@ -145,7 +143,7 @@ intn HDGLadd_to_end(Generic_list list, /*IN: list */
      SUCCEED/FAIL
 *******************************************************************************/
 intn HDGLadd_to_list(Generic_list list, /*IN: list */
-                     VOIDP pointer /*IN: data element */);
+                     void        *pointer /*IN: data element */);
 
 /******************************************************************************
  NAME
@@ -156,7 +154,7 @@ intn HDGLadd_to_list(Generic_list list, /*IN: list */
  RETURNS
     First Element if successful and NULL otherwise.
 *******************************************************************************/
-VOIDP HDGLremove_from_beginning(Generic_list list /*IN: list */);
+void *HDGLremove_from_beginning(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -165,9 +163,9 @@ VOIDP HDGLremove_from_beginning(Generic_list list /*IN: list */);
     This function will remove the last object from the end of the list and
     return it.  If the list is empty, NULL is returned.
  RETURNS
-    Last element if successfull and NULL otherwise
+    Last element if successful and NULL otherwise
 *******************************************************************************/
-VOIDP HDGLremove_from_end(Generic_list list /*IN: list */);
+void *HDGLremove_from_end(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -181,8 +179,8 @@ VOIDP HDGLremove_from_end(Generic_list list /*IN: list */);
  RETURNS
     Element removed if successful and NULL otherwise
 *******************************************************************************/
-VOIDP HDGLremove_from_list(Generic_list list, /*IN: list */
-                           VOIDP pointer /*IN: data element */);
+void *HDGLremove_from_list(Generic_list list, /*IN: list */
+                           void        *pointer /*IN: data element */);
 
 /******************************************************************************
  NAME
@@ -195,7 +193,7 @@ VOIDP HDGLremove_from_list(Generic_list list, /*IN: list */
  RETURNS
     Current element if successful and NULL otherwise.
 *******************************************************************************/
-VOIDP HDGLremove_current(Generic_list list /*IN: list */);
+void *HDGLremove_current(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -219,7 +217,7 @@ void HDGLremove_all(Generic_list list /*IN: list */);
  RETURNS
     First element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLpeek_at_beginning(Generic_list list /*IN: list */);
+void *HDGLpeek_at_beginning(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -230,7 +228,7 @@ VOIDP HDGLpeek_at_beginning(Generic_list list /*IN: list */);
  RETURNS
     Last element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLpeek_at_end(Generic_list list /*IN: list */);
+void *HDGLpeek_at_end(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -241,7 +239,7 @@ VOIDP HDGLpeek_at_end(Generic_list list /*IN: list */);
  RETURNS
     First element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLfirst_in_list(Generic_list list /*IN: list */);
+void *HDGLfirst_in_list(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -255,7 +253,7 @@ VOIDP HDGLfirst_in_list(Generic_list list /*IN: list */);
  RETURNS
     Current element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLcurrent_in_list(Generic_list list /*IN: list */);
+void *HDGLcurrent_in_list(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -266,7 +264,7 @@ VOIDP HDGLcurrent_in_list(Generic_list list /*IN: list */);
  RETURNS
     Last element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLlast_in_list(Generic_list list /*IN: list */);
+void *HDGLlast_in_list(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -278,7 +276,7 @@ VOIDP HDGLlast_in_list(Generic_list list /*IN: list */);
  RETURNS
     Next element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLnext_in_list(Generic_list list /*IN: list */);
+void *HDGLnext_in_list(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -290,7 +288,7 @@ VOIDP HDGLnext_in_list(Generic_list list /*IN: list */);
  RETURNS
     Previous element in list if non-empty, otherwise NULL.
 *******************************************************************************/
-VOIDP HDGLprevious_in_list(Generic_list list /*IN: list */);
+void *HDGLprevious_in_list(Generic_list list /*IN: list */);
 
 /******************************************************************************
  NAME
@@ -341,13 +339,13 @@ intn HDGLis_empty(Generic_list list /*IN: list */);
  NAME
      HDGLis_in_list
  DESCRIPTION
-     Detemines if the object is in the list.
+     Determines if the object is in the list.
  RETURNS
     This function will return TRUE (1) if the specified object is a member
     of the list, and FALSE (0) otherwise.
 *******************************************************************************/
 intn HDGLis_in_list(Generic_list list, /*IN: list */
-               VOIDP pointer /*IN: data element */);
+                    void        *pointer /*IN: data element */);
 
 /******************************************************************************
  NAME
@@ -357,7 +355,7 @@ intn HDGLis_in_list(Generic_list list, /*IN: list */
     are not copied; only new references to them are made.  The new list
     loses its concept of the current object.
  RETURNS
-    A copy of the orginal list.
+    A copy of the original list.
 *******************************************************************************/
 Generic_list HDGLcopy_list(Generic_list list /*IN: list */);
 
@@ -370,9 +368,9 @@ Generic_list HDGLcopy_list(Generic_list list /*IN: list */);
  RETURNS
     Nothing
 *******************************************************************************/
-void HDGLperform_on_list(Generic_list list, /*IN: list */
-                         void (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                         VOIDP args /*IN: args to iterator fcn */);
+void HDGLperform_on_list(Generic_list list,                     /*IN: list */
+                         void (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                         void *args /*IN: args to iterator fcn */);
 
 /******************************************************************************
  NAME
@@ -386,9 +384,9 @@ void HDGLperform_on_list(Generic_list list, /*IN: list */
  RETURNS
      Element if successful and NULL otherwise.
 *******************************************************************************/
-VOIDP HDGLfirst_that(Generic_list list, /*IN: list */
-                     intn (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                     VOIDP args /*IN: args to iterator fcn */);
+void *HDGLfirst_that(Generic_list list,                     /*IN: list */
+                     intn (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                     void *args /*IN: args to iterator fcn */);
 
 /******************************************************************************
  NAME
@@ -403,9 +401,9 @@ VOIDP HDGLfirst_that(Generic_list list, /*IN: list */
  RETURNS
      Element if successful and NULL otherwise.
 *******************************************************************************/
-VOIDP HDGLnext_that(Generic_list list, /*IN: list */
-                    intn (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                    VOIDP args /*IN: args to iterator fcn */);
+void *HDGLnext_that(Generic_list list,                     /*IN: list */
+                    intn (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                    void *args /*IN: args to iterator fcn */);
 
 /******************************************************************************
  NAME
@@ -420,9 +418,9 @@ VOIDP HDGLnext_that(Generic_list list, /*IN: list */
  RETURNS
      Element if successful and NULL otherwise.
 *******************************************************************************/
-VOIDP HDGLprevious_that(Generic_list list, /*IN: list */
-                        intn (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                        VOIDP args /*IN: args to iterator fcn */);
+void *HDGLprevious_that(Generic_list list,                     /*IN: list */
+                        intn (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                        void *args /*IN: args to iterator fcn */);
 
 /******************************************************************************
  NAME
@@ -436,9 +434,9 @@ VOIDP HDGLprevious_that(Generic_list list, /*IN: list */
  RETURNS
      Element if successful and NULL otherwise.
 *******************************************************************************/
-VOIDP HDGLlast_that(Generic_list list, /*IN: list */
-                    intn (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                    VOIDP args /*IN: args to iterator fcn */);
+void *HDGLlast_that(Generic_list list,                     /*IN: list */
+                    intn (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                    void *args /*IN: args to iterator fcn */);
 
 /******************************************************************************
  NAME
@@ -452,9 +450,9 @@ VOIDP HDGLlast_that(Generic_list list, /*IN: list */
  RETURNS
     New list if successful and empty if not.
 *******************************************************************************/
-Generic_list HDGLall_such_that(Generic_list list, /*IN: list */
-                               intn (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                               VOIDP args /*IN: args to iterator fcn */);
+Generic_list HDGLall_such_that(Generic_list list,                     /*IN: list */
+                               intn (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                               void *args /*IN: args to iterator fcn */);
 
 /******************************************************************************
  NAME
@@ -469,14 +467,13 @@ Generic_list HDGLall_such_that(Generic_list list, /*IN: list */
  RETURNS
      Nothing
 *******************************************************************************/
-void HDGLremove_all_such_that(Generic_list list, /*IN: list */
-                              intn (*fn)(VOIDP pointer, VOIDP args), /* IN: iterator fcn */
-                              VOIDP args /*IN: args to iterator fcn */);
-
+void HDGLremove_all_such_that(Generic_list list,                     /*IN: list */
+                              intn (*fn)(void *pointer, void *args), /* IN: iterator fcn */
+                              void *args /*IN: args to iterator fcn */);
 
 /****************************************************************************/
-/* 
- * Stack operations 
+/*
+ * Stack operations
  */
 
 /******************************************************************************
@@ -492,7 +489,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
 
 /******************************************************************************
  NAME
-     HDGSdestroy_stack     
+     HDGSdestroy_stack
  DESCRIPTION
     When a stack is no longer needed, it should be destroyed.  This process
     will automatically remove all remaining objects from the stack.
@@ -505,7 +502,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      Nothing
 *******************************************************************************/
-#define HDGSdestroy_stack    HDGLdestroy_list
+#define HDGSdestroy_stack HDGLdestroy_list
 
 /******************************************************************************
  NAME
@@ -516,7 +513,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      SUCCEED/FAIL
 *******************************************************************************/
-#define HDGSpush             HDGLadd_to_beginning
+#define HDGSpush HDGLadd_to_beginning
 
 /******************************************************************************
  NAME
@@ -527,7 +524,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      First element of the top of the stack
 *******************************************************************************/
-#define HDGSpop              HDGLremove_from_beginning
+#define HDGSpop HDGLremove_from_beginning
 
 /******************************************************************************
  NAME
@@ -540,7 +537,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      Nothing
 *******************************************************************************/
-#define HDGSpop_all          HDGLremove_all
+#define HDGSpop_all HDGLremove_all
 
 /******************************************************************************
  NAME
@@ -551,7 +548,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      Element at top of stack.
 *******************************************************************************/
-#define HDGSpeek_at_top      HDGLpeek_at_beginning
+#define HDGSpeek_at_top HDGLpeek_at_beginning
 
 /******************************************************************************
  NAME
@@ -562,12 +559,11 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      SUCCEED/FAIL
 *******************************************************************************/
-#define HDGScopy_stack       HDGLcopy_list
-
+#define HDGScopy_stack HDGLcopy_list
 
 /****************************************************************************/
-/* 
- * Queue operations 
+/*
+ * Queue operations
  */
 
 /******************************************************************************
@@ -596,18 +592,18 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      SUCCEED/FAIL
 *******************************************************************************/
-#define HDGQdestroy_queue    HDGLdestroy_list
+#define HDGQdestroy_queue HDGLdestroy_list
 
 /******************************************************************************
  NAME
-     HDGQenqueue     
+     HDGQenqueue
  DESCRIPTION
     This function will add the specified object to the tail of the queue.
     The pointer must not be NULL.
  RETURNS
      SUCCEED/FAIL
 *******************************************************************************/
-#define HDGQenqueue          HDGLadd_to_end
+#define HDGQenqueue HDGLadd_to_end
 
 /******************************************************************************
  NAME
@@ -618,7 +614,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
     First element in the queue in non-empty, else NULL.
 *******************************************************************************/
-#define HDGQdequeue          HDGLremove_from_beginning
+#define HDGQdequeue HDGLremove_from_beginning
 
 /******************************************************************************
  NAME
@@ -631,7 +627,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      Nothing
 *******************************************************************************/
-#define HDGQdequeue_all      HDGLremove_all
+#define HDGQdequeue_all HDGLremove_all
 
 /******************************************************************************
  NAME
@@ -642,7 +638,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
     First element in the queue in non-empty, else NULL.
 *******************************************************************************/
-#define HDGQpeek_at_head     HDGLpeek_at_beginning
+#define HDGQpeek_at_head HDGLpeek_at_beginning
 
 /******************************************************************************
  NAME
@@ -653,7 +649,7 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
     Last element in the queue in non-empty, else NULL.
 *******************************************************************************/
-#define HDGQpeek_at_tail     HDGLpeek_at_end
+#define HDGQpeek_at_tail HDGLpeek_at_end
 
 /******************************************************************************
  NAME
@@ -664,7 +660,6 @@ void HDGLremove_all_such_that(Generic_list list, /*IN: list */
  RETURNS
      SUCCEED/FAIL
 *******************************************************************************/
-#define HDGQcopy_queue       HDGLcopy_list
-
-#endif /* GLIST_H */
+#define HDGQcopy_queue HDGLcopy_list
 
+#endif /* H4_GLIST_H */
