@@ -11,8 +11,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id$ */
-
 #include "hdf.h"
 #include "fortest.h"
 
@@ -23,20 +21,19 @@
  * Inputs:  NONE
  * Returns: verbosity level on success, FAIL on failure
  * Users:   HDF Fortran programmers
- * Invokes: HDgetenv
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
 ngetverb(void)
 {
     char *verb_str;
-    intn verb_level=FAIL;
-    verb_str=HDgetenv(FOR_VERB);
+    intn  verb_level = FAIL;
+    verb_str         = getenv(FOR_VERB);
 
-    if(verb_str!=NULL)
-        verb_level=(intn)HDstrtol(verb_str,NULL,0); /* convert whole string using base 10 */
-    return((intf)verb_level);
-}   /* end getverb() */
+    if (verb_str != NULL)
+        verb_level = (intn)HDstrtol(verb_str, NULL, 0); /* convert whole string using base 10 */
+    return ((intf)verb_level);
+} /* end getverb() */
 
 /*-----------------------------------------------------------------------------
  * Name:    hisystem
@@ -51,39 +48,41 @@ ngetverb(void)
 FRETVAL(intf)
 nhisystem(_fcd cmd, intf *cmdlen)
 {
-    char       *fn;
-    intf        ret;
+    char *fn;
+    intf  ret;
 
-    fn = HDf2cstring(cmd, (intn) *cmdlen);
-    if (!fn) return(FAIL);
-    ret = (intf) system(fn);
-    HDfree(fn);
+    fn = HDf2cstring(cmd, (intn)*cmdlen);
+    if (!fn)
+        return (FAIL);
+    ret = (intf)system(fn);
+    free(fn);
     return (ret);
-}   /* end nhisystem() */
+} /* end nhisystem() */
 
 /*-----------------------------------------------------------------------------
  * Name:    fixname
  * Purpose: Fix name for srcdir build and test
- * Inputs:  IN: name - original namea 
+ * Inputs:  IN: name - original namea
  *          IN: name_len - name length
  *          IN/OUT: name_out - buffer to hold modified name
  *          IN/OUT: name_out_len - length of the buffer, and length of modified
- *                  string. 
- * Returns: 0 on success and -1 on failure  
+ *                  string.
+ * Returns: 0 on success and -1 on failure
  * Users:   HDF Fortran programmers
  *---------------------------------------------------------------------------*/
 
 FRETVAL(intf)
 nfixnamec(_fcd name, intf *name_len, _fcd name_out, intf *name_len_out)
 {
-    char       *c_name;
-    intf        ret;
+    char *c_name;
+    intf  ret;
 
-    char    testfile[1024] = "";
-    char   *srcdir = getenv("srcdir");
+    char  testfile[1024] = "";
+    char *srcdir         = getenv("srcdir");
 
-    c_name = HDf2cstring(name, (intn) *name_len);
-    if (!c_name) return(FAIL);
+    c_name = HDf2cstring(name, (intn)*name_len);
+    if (!c_name)
+        return (FAIL);
 
     /* Here comes Bill's code */
     /* Generate the correct name for the test file, by prepending the source path */
@@ -92,10 +91,10 @@ nfixnamec(_fcd name, intf *name_len, _fcd name_out, intf *name_len_out)
         strcat(testfile, "/");
     }
     strcat(testfile, c_name);
-    *name_len_out = (intf) strlen(testfile);
+    *name_len_out = (intf)strlen(testfile);
     HDpackFstring(testfile, _fcdtocp(name_out), *name_len_out);
- 
+
     ret = 0;
-    HDfree(c_name);
+    free(c_name);
     return (ret);
-}   /* end nfixname() */
+} /* end nfixname() */
