@@ -11,20 +11,18 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id$ */
-
-#ifndef __FORTEST_H
-#define __FORTEST_H
+#ifndef H4_FORTEST_H
+#define H4_FORTEST_H
 
 #include "H4api_adpt.h"
 #include "hdf.h"
 
 /* Verbosity Environment Variable */
-#define FOR_VERB    "HDF_FOR_VERBOSITY"
+#define FOR_VERB "HDF_FOR_VERBOSITY"
 
-#  define ngetverb      H4_F77_FUNC(getverb, GETVERB)
-#  define nhisystem     H4_F77_FUNC(hisystem, HISYSTEM)
-#  define nfixnamec     H4_F77_FUNC(fixnamec, FIXNAMEC) 
+#define ngetverb  H4_F77_FUNC(getverb, GETVERB)
+#define nhisystem H4_F77_FUNC(hisystem, HISYSTEM)
+#define nfixnamec H4_F77_FUNC(fixnamec, FIXNAMEC)
 
 /* FORTRAN support C-stubs for FORTRAN interface tests */
 
@@ -32,5 +30,4 @@ HDFFCLIBAPI FRETVAL(intf) ngetverb(void);
 HDFFCLIBAPI FRETVAL(intf) nhisystem(_fcd cmd, intf *cmdlen);
 HDFFCLIBAPI FRETVAL(intf) nfixnamec(_fcd name, intf *name_len, _fcd name_out, intf *name_len_out);
 
-#endif /* __FORTEST_H */
-
+#endif /* H4_FORTEST_H */
