@@ -21,9 +21,9 @@ package hdf.hdflib;
  */
 
 public class HDFCompInfo {
+    /** */
     public int ctype;
 
-    public HDFCompInfo() {
-        ctype = HDFConstants.COMP_CODE_NONE;
-    };
+    /** */
+    public HDFCompInfo() { ctype = HDFConstants.COMP_CODE_NONE; };
 }
