@@ -22,23 +22,28 @@ package hdf.hdflib;
 
 public class HDFNBITChunkInfo extends HDFChunkInfo {
 
+    /** */
     public int[] chunk_lengths = new int[HDFConstants.MAX_VAR_DIMS];
+    /** */
     public int start_bit = 0;
+    /** */
     public int bit_len = 0;
+    /** */
     public int sign_ext = 0;
+    /** */
     public int fill_one = 0;
 
-    public HDFNBITChunkInfo() {
-        ctype = HDFConstants.HDF_NBIT;
-    };
+    /** */
+    public HDFNBITChunkInfo() { ctype = HDFConstants.HDF_NBIT; };
 
-    public HDFNBITChunkInfo(int[] cl, int sb, int bl, int se, int fo) {
-        ctype = HDFConstants.HDF_NBIT;
+    /** */
+    public HDFNBITChunkInfo(int[] cl, int sb, int bl, int se, int fo)
+    {
+        ctype         = HDFConstants.HDF_NBIT;
         chunk_lengths = cl;
-        start_bit = sb;
-        bit_len = bl;
-        sign_ext = se;
-        fill_one = fo;
+        start_bit     = sb;
+        bit_len       = bl;
+        sign_ext      = se;
+        fill_one      = fo;
     }
-
 }
