@@ -22,9 +22,9 @@ package hdf.hdflib;
  */
 
 public class HDFOldCompInfo extends HDFCompInfo {
-    public int ctype; /* from COMP_NONE defines */
+    /** from COMP_NONE defines */
+    public int ctype;
 
-    public HDFOldCompInfo() {
-        ctype = HDFConstants.COMP_NONE;
-    };
+    /** */
+    public HDFOldCompInfo() { ctype = HDFConstants.COMP_NONE; };
 }
