@@ -18,13 +18,11 @@ package hdf.hdflib;
  * This class is a generic container for the parameters to the HDF RLE compressed classes, with the
  * ``old'' type encoding.
  * <p>
- * In this case, there is no auxilliary information.
+ * In this case, there is no auxiliary information.
  */
 
 public class HDFOldRLECompInfo extends HDFOldCompInfo {
 
-    public HDFOldRLECompInfo() {
-        ctype = HDFConstants.COMP_RLE;
-    }
-
+    /** */
+    public HDFOldRLECompInfo() { ctype = HDFConstants.COMP_RLE; }
 }
