@@ -11,13 +11,11 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 
 #include "hdiff_mattbl.h"
 
-
 /*-------------------------------------------------------------------------
  * Function: match_table_add
  *
@@ -37,19 +35,15 @@
  *-------------------------------------------------------------------------
  */
 
-void match_table_add (match_table_t *table, 
-                      unsigned *flags, 
-                      char* path, 
-                      int32 tag1, 
-                      int32 ref1,
-                      int32 tag2, 
-                      int32 ref2 )
+void
+match_table_add(match_table_t *table, unsigned *flags, char *path, int32 tag1, int32 ref1, int32 tag2,
+                int32 ref2)
 {
     uint32 i;
-    
+
     if (table->nobjs == table->size) {
         table->size *= 2;
-        table->objs = (match_info_t*)HDrealloc(table->objs, table->size * sizeof(match_info_t));
+        table->objs = (match_info_t *)realloc(table->objs, table->size * sizeof(match_info_t));
 
         for (i = table->nobjs; i < table->size; i++) {
             table->objs[i].tag1 = table->objs[i].ref1 = -1;
@@ -57,18 +51,17 @@ void match_table_add (match_table_t *table,
             table->objs[i].flags[0] = table->objs[i].flags[1] = -1;
         }
     }
-    
-    i = table->nobjs++;
+
+    i                   = table->nobjs++;
     table->objs[i].tag1 = tag1;
     table->objs[i].ref1 = ref1;
     table->objs[i].tag2 = tag2;
     table->objs[i].ref2 = ref2;
-    HDstrcpy(table->objs[i].obj_name,path);
+    HDstrcpy(table->objs[i].obj_name, path);
     table->objs[i].flags[0] = flags[0];
     table->objs[i].flags[1] = flags[1];
 }
 
-
 /*-------------------------------------------------------------------------
  * Function: match_table_init
  *
@@ -83,26 +76,25 @@ void match_table_add (match_table_t *table,
  *-------------------------------------------------------------------------
  */
 
-void match_table_init( match_table_t **tbl )
+void
+match_table_init(match_table_t **tbl)
 {
-    uint32 i;
-    match_table_t* table = (match_table_t*)HDmalloc(sizeof(match_table_t));
+    uint32         i;
+    match_table_t *table = (match_table_t *)malloc(sizeof(match_table_t));
 
-    table->size = 20;
+    table->size  = 20;
     table->nobjs = 0;
-    table->objs = (match_info_t*)HDmalloc(table->size * sizeof(match_info_t));
+    table->objs  = (match_info_t *)malloc(table->size * sizeof(match_info_t));
 
     for (i = 0; i < table->size; i++) {
         table->objs[i].tag1 = table->objs[i].ref1 = -1;
         table->objs[i].tag2 = table->objs[i].ref2 = -1;
         table->objs[i].flags[0] = table->objs[i].flags[1] = -1;
     }
-    
+
     *tbl = table;
 }
 
-
-
 /*-------------------------------------------------------------------------
  * Function: match_table_free
  *
@@ -117,11 +109,9 @@ void match_table_init( match_table_t **tbl )
  *-------------------------------------------------------------------------
  */
 
-void match_table_free( match_table_t *table )
+void
+match_table_free(match_table_t *table)
 {
-    HDfree(table->objs);
-    HDfree(table);
+    free(table->objs);
+    free(table);
 }
-
-
-
