@@ -50,7 +50,7 @@ LOCAL ROUTINES
 #endif
 #include "mfhdf.h"
 
-#ifdef H4_HAVE_LIBSZ          /* we have the szip library */
+#ifdef H4_HAVE_LIBSZ /* we have the szip library */
 #include "szlib.h"
 #endif
 
@@ -63,7 +63,7 @@ LOCAL ROUTINES
 #include "mfprivate.h"
 #endif
 
-PRIVATE intn get_attr_tag(char *attr_name, uint16* attr_tag);
+static intn get_attr_tag(char *attr_name, uint16 *attr_tag);
 
 /******************************************************************************
  NAME
@@ -103,13 +103,12 @@ PRIVATE intn get_attr_tag(char *attr_name, uint16* attr_tag);
 
  ******************************************************************************/
 intn
-SDgetdatainfo(int32 sdsid, int32 *chk_coord, uintn start_block,
-        uintn info_count, int32 *offsetarray, int32 *lengtharray)
+SDgetdatainfo(int32 sdsid, int32 *chk_coord, uintn start_block, uintn info_count, int32 *offsetarray,
+              int32 *lengtharray)
 {
-    CONSTR(FUNC, "SDgetdatainfo");    /* for HGOTO_ERROR */
     NC     *handle;
     NC_var *var;
-    intn    count = FAIL; /* number of data blocks */
+    intn    count     = FAIL; /* number of data blocks */
     intn    ret_value = 0;
 
     /* Clear error stack */
@@ -118,8 +117,7 @@ SDgetdatainfo(int32 sdsid, int32 *chk_coord, uintn start_block,
     /* Validate arguments */
 
     /* Getting only offsets or lengths is not allowed */
-    if ((offsetarray != NULL && lengtharray == NULL) ||
-            (offsetarray == NULL && lengtharray != NULL))
+    if ((offsetarray != NULL && lengtharray == NULL) || (offsetarray == NULL && lengtharray != NULL))
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* Just in case user forgot to allocate buffers */
@@ -128,52 +126,42 @@ SDgetdatainfo(int32 sdsid, int32 *chk_coord, uintn start_block,
 
     /* Get NC_var record */
     handle = SDIhandle_from_id(sdsid, SDSTYPE);
-    if(handle == NULL || handle->file_type != HDF_FILE)
+    if (handle == NULL || handle->file_type != HDF_FILE)
         HGOTO_ERROR(DFE_ARGS, FAIL);
-    if(handle->vars == NULL)
+    if (handle->vars == NULL)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     var = SDIget_var(handle, sdsid);
-    if(var == NULL)
+    if (var == NULL)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* If the data ref# of the SDS is 0, there is no storage is created yet */
-    if (var->data_ref == 0)
-    {
+    if (var->data_ref == 0) {
         count = 0; /* no blocks */
     }
-    else
-    {
+    else {
         /* If both arrays are NULL, get the number of data blocks and return */
-        if (offsetarray == NULL && lengtharray == NULL)
-        {
-            count = HDgetdatainfo(handle->hdf_file, var->data_tag,
-                    var->data_ref, chk_coord, start_block, info_count, NULL, NULL);
+        if (offsetarray == NULL && lengtharray == NULL) {
+            count = HDgetdatainfo(handle->hdf_file, var->data_tag, var->data_ref, chk_coord, start_block,
+                                  info_count, NULL, NULL);
             if (count == FAIL)
                 HGOTO_ERROR(DFE_INTERNAL, FAIL);
         }
 
         /* Application requests actual offsets/lengths */
-        else
-        {
-            count = HDgetdatainfo(handle->hdf_file, var->data_tag,
-                    var->data_ref, chk_coord, start_block, info_count,
-                    offsetarray, lengtharray);
+        else {
+            count = HDgetdatainfo(handle->hdf_file, var->data_tag, var->data_ref, chk_coord, start_block,
+                                  info_count, offsetarray, lengtharray);
             if (count == FAIL)
                 HGOTO_ERROR(DFE_INTERNAL, FAIL);
         }
     }
     /* Returning number of data blocks */
     ret_value = count;
-    done:
-    if (ret_value == FAIL)
-    { /* Failure cleanup */
-    }
-    /* Normal cleanup */
+done:
     return ret_value;
 } /* SDgetdatainfo */
 
-
 /******************************************************************************
  NAME
     SDgetattdatainfo -- Retrieves location and size of attribute's data.
@@ -209,24 +197,23 @@ SDgetdatainfo(int32 sdsid, int32 *chk_coord, uintn start_block,
 intn
 SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
 {
-    CONSTR(FUNC, "SDgetattdatainfo");
     NC     *handle;
     NC_var *var;
     NC_dim *dim;
-    int32   vg_ref=0,  /* ref# of the VG representing a file, SDS, or dim */
-            n_elements,  /* number of elements in the file/SDS/dim vgroup */
-            vs_id=-1,  /* VS id, needed while looking for _HDF_ATTRIBUTE */
-            vg_id=-1,  /* id of the file/SDS/dimension vgroup */
-            var_idx;  /* index of the variable representing the given dim */
-    char    vsclass[H4_MAX_NC_CLASS] = "", /* vs class, is it _HDF_ATTRIBUTE? */
-            attrname[H4_MAX_NC_CLASS] = "",/* name of the given attribute */
-            vsname[H4_MAX_NC_CLASS] = "";  /* vs name to see if it's the inquired attr's name*/
-    int32   ntype=0,  /* need these because SDattrinfo doesn't... */
-            count=0;  /* ...take NULL pointers for not needed arguments */
-    int     ii;
-    intn    status,  /* returned value */
-    found,  /* TRUE when attribute is found */
-    ret_value = SUCCEED;
+    int32   vg_ref = 0,                 /* ref# of the VG representing a file, SDS, or dim */
+        n_elements,                     /* number of elements in the file/SDS/dim vgroup */
+        vs_id = -1,                     /* VS id, needed while looking for _HDF_ATTRIBUTE */
+        vg_id = -1,                     /* id of the file/SDS/dimension vgroup */
+        var_idx;                        /* index of the variable representing the given dim */
+    char vsclass[H4_MAX_NC_CLASS] = "", /* vs class, is it _HDF_ATTRIBUTE? */
+        attrname[H4_MAX_NC_CLASS] = "", /* name of the given attribute */
+        vsname[H4_MAX_NC_CLASS]   = ""; /* vs name to see if it's the inquired attr's name*/
+    int32 ntype                   = 0,  /* need these because SDattrinfo doesn't... */
+        count                     = 0;  /* ...take NULL pointers for not needed arguments */
+    int  ii;
+    intn status, /* returned value */
+        found,   /* TRUE when attribute is found */
+        ret_value = SUCCEED;
 
     /* Clear error stack */
     HEclear();
@@ -243,40 +230,40 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
 
     /* Get the attribute's name */
     status = SDattrinfo(id, attrindex, attrname, &ntype, &count);
+    if (status == FAIL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* Check if the id given is a file id, or SDS id, or dimension id, and get
        appropriate info structure */
     handle = SDIhandle_from_id(id, CDFTYPE);
 
     /* not a file id */
-    if(handle == NULL)
-    {
+    if (handle == NULL) {
         /* then check if it's SDS id */
         handle = SDIhandle_from_id(id, SDSTYPE);
         /* not an SDS id */
-        if(handle == NULL)
-        {
+        if (handle == NULL) {
             /* then check if it's a dimension id */
             handle = SDIhandle_from_id(id, DIMTYPE);
 
             /* not a dimension id either, return with an error */
-            if(handle == NULL)
+            if (handle == NULL)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
 
             /* dimension id is given, get the dimension info */
             dim = SDIget_dim(handle, id);
-            if(dim == NULL)
+            if (dim == NULL)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
 
             /* look for the variable representing this dimension,
        ie. coordinate variable */
             var_idx = SDIgetcoordvar(handle, dim, id, (int32)0);
-            if(var_idx == FAIL)
+            if (var_idx == FAIL)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
 
             /* get the variable object */
             var = NC_hlookupvar(handle, var_idx);
-            if(var == NULL)
+            if (var == NULL)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
 
             /* get the ref number of the vgroup representing this dim */
@@ -290,13 +277,12 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
                 HGOTO_DONE(DFE_NOVGREP);
         }
         /* SDS id is given */
-        else
-        {
+        else {
             /* get the variable record */
-            if(handle->vars == NULL)
+            if (handle->vars == NULL)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
             var = SDIget_var(handle, id);
-            if(var == NULL)
+            if (var == NULL)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
 
             /* get the reference number of the vgroup representing this SDS */
@@ -311,10 +297,9 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
         }
     }
     /* File id is given */
-    else
-    {
+    else {
         /* make sure it is an HDF file */
-        if(handle->file_type != HDF_FILE)
+        if (handle->file_type != HDF_FILE)
             HGOTO_ERROR(DFE_ARGS, FAIL);
 
         /* get the reference number of the vgroup representing the file */
@@ -324,12 +309,13 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
      so no special handling for DFE_NOVGREP here. -BMR 2011/1/11 */
 
         /* Validate the vgroup ref# */
-        if (vg_ref == 0) HGOTO_ERROR(DFE_ARGS, FAIL);
+        if (vg_ref == 0)
+            HGOTO_ERROR(DFE_ARGS, FAIL);
     }
 
     /* Get access to the vgroup and get the number of elements belong to it */
     vg_id = Vattach(handle->hdf_file, vg_ref, "r");
-    if(vg_id == FAIL) 
+    if (vg_id == FAIL)
         HGOTO_ERROR(DFE_CANTATTACH, FAIL);
     n_elements = Vntagrefs(vg_id);
     if (n_elements == FAIL)
@@ -340,8 +326,7 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
        matches, use VSgetdatainfo to get offset and length of the attribute's
        data, then set flag to terminate the search */
     found = FALSE;
-    for (ii = 0; ii < n_elements && !found; ii++) 
-    {
+    for (ii = 0; ii < n_elements && !found; ii++) {
         int32 elem_tag, elem_ref;
 
         /* get current tag/ref */
@@ -349,10 +334,9 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
             HGOTO_ERROR(DFE_INTERNAL, FAIL);
 
         /* current element is a vdata */
-        if(elem_tag == DFTAG_VH) 
-        {
+        if (elem_tag == DFTAG_VH) {
             vs_id = VSattach(handle->hdf_file, elem_ref, "r");
-            if(vs_id == FAIL) 
+            if (vs_id == FAIL)
                 HGOTO_ERROR(DFE_CANTATTACH, FAIL);
 
             /* get the vdata's class */
@@ -360,16 +344,14 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
                 HGOTO_ERROR(DFE_INTERNAL, FAIL);
 
             /* current vdata represents an attribute */
-            if(!HDstrcmp(vsclass, _HDF_ATTRIBUTE)) 
-            {
+            if (!HDstrcmp(vsclass, _HDF_ATTRIBUTE)) {
                 /* get the vdata's name */
                 if (VSgetname(vs_id, vsname) == FAIL)
                     HGOTO_ERROR(DFE_INTERNAL, FAIL);
 
                 /* the searched attribute if found */
-                if (!HDstrcmp(attrname, vsname))
-                {
-                    intn info_count=0;
+                if (!HDstrcmp(attrname, vsname)) {
+                    intn info_count = 0;
 
                     /* get offset/length of attribute's data */
                     info_count = VSgetdatainfo(vs_id, 0, 1, offset, length);
@@ -379,7 +361,7 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
                         HGOTO_ERROR(DFE_INTERNAL, FAIL);
 
                     /* set flag to terminate the search, and return info count*/
-                    found = TRUE;
+                    found     = TRUE;
                     ret_value = info_count;
                 }
             }
@@ -393,9 +375,8 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
     if (Vdetach(vg_id) == FAIL)
         HGOTO_ERROR(DFE_CANTDETACH, FAIL);
 
-    done:
-    if (ret_value == FAIL)
-    { /* Failure cleanup */
+done:
+    if (ret_value == FAIL) { /* Failure cleanup */
         if (vs_id != -1)
             if (VSdetach(vs_id) == FAIL)
                 HGOTO_ERROR(DFE_CANTDETACH, FAIL);
@@ -403,12 +384,10 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
             if (Vdetach(vg_id) == FAIL)
                 HGOTO_ERROR(DFE_CANTDETACH, FAIL);
     }
-    /* Normal cleanup */
 
     return ret_value;
 } /* SDgetattdatainfo */
 
-
 /******************************************************************************
  NAME
     get_attr_tag -- Convert the name of a pre-defined attribute to its
@@ -431,8 +410,8 @@ SDgetattdatainfo(int32 id, int32 attrindex, int32 *offset, int32 *length)
     application can use tag/ref to read the attribute string.
 
  ******************************************************************************/
-PRIVATE intn 
-get_attr_tag(char *attr_name, uint16* attr_tag)
+static intn
+get_attr_tag(char *attr_name, uint16 *attr_tag)
 {
     intn ret_value = SUCCEED;
 
@@ -444,24 +423,20 @@ get_attr_tag(char *attr_name, uint16* attr_tag)
         *attr_tag = DFTAG_SDF;
     else if (HDstrcmp(_HDF_CoordSys, attr_name) == 0)
         *attr_tag = DFTAG_SDC;
-    else if ((HDstrcmp(_HDF_ValidMin, attr_name) == 0) ||
-            (HDstrcmp(_HDF_ValidMax, attr_name) == 0) ||
-            (HDstrcmp(_HDF_ValidRange, attr_name) == 0))
+    else if ((HDstrcmp(_HDF_ValidMin, attr_name) == 0) || (HDstrcmp(_HDF_ValidMax, attr_name) == 0) ||
+             (HDstrcmp(_HDF_ValidRange, attr_name) == 0))
         *attr_tag = DFTAG_SDM;
     else if (HDstrcmp(_FillValue, attr_name) == 0)
         *attr_tag = DFTAG_FV;
-    else if ((HDstrcmp(_HDF_CalibratedNt, attr_name) == 0)
-            || (HDstrcmp(_HDF_ScaleFactor, attr_name) == 0)
-            || (HDstrcmp(_HDF_ScaleFactorErr, attr_name) == 0)
-            || (HDstrcmp(_HDF_AddOffset, attr_name) == 0)
-            || (HDstrcmp(_HDF_AddOffsetErr, attr_name) == 0))
+    else if ((HDstrcmp(_HDF_CalibratedNt, attr_name) == 0) || (HDstrcmp(_HDF_ScaleFactor, attr_name) == 0) ||
+             (HDstrcmp(_HDF_ScaleFactorErr, attr_name) == 0) || (HDstrcmp(_HDF_AddOffset, attr_name) == 0) ||
+             (HDstrcmp(_HDF_AddOffsetErr, attr_name) == 0))
         *attr_tag = DFTAG_CAL;
     /* We need to decide how to handle this attribute when we see it...
-    else 
+    else
             case DFTAG_SDLNK:
      */
-    else
-    {
+    else {
         ret_value = FAIL;
         fprintf(stderr, "get_attr_tag: attr_name = <%s> is not recognized currently\n", attr_name);
     }
@@ -514,23 +489,18 @@ get_attr_tag(char *attr_name, uint16* attr_tag)
 
  ******************************************************************************/
 intn
-SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
-        int32 *offset, int32 *length)
+SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char *attr_name, int32 *offset, int32 *length)
 {
-    CONSTR(FUNC, "SDgetoldattdatainfo");
     NC     *handle;
     NC_var *var;
-    int32   off, len,
-    dim_att_len=0,
-    sdsluf_len=0,
-    offp = 0;
-    char   *lufbuf=NULL, *lufp=NULL;
+    int32   off, len, dim_att_len = 0, sdsluf_len = 0, offp = 0;
+    char   *lufbuf = NULL, *lufp = NULL;
     uint16  att_tag, att_ref;
-    intn    dimidx_infile=0, dimidx_invar=0;
+    intn    dimidx_infile = 0, dimidx_invar = 0;
     intn    isdim = 0;
     int     ii;
-    intn    status,  /* returned value */
-    ret_value = 0;
+    intn    status, /* returned value */
+        ret_value = 0;
 
     /* Clear error stack */
     HEclear();
@@ -545,18 +515,18 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
 
     /* Check if a dimension ID is given then set flag */
     handle = SDIhandle_from_id(dim_id, DIMTYPE);
-    if(handle != NULL)
+    if (handle != NULL)
         isdim = 1;
 
     /* Check if the given dataset ID really is a dataset ID; dataset ID
        must always be available */
     handle = SDIhandle_from_id(sdsid, SDSTYPE);
-    if(handle == NULL)
+    if (handle == NULL)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* Get the variable object of the dataset */
     var = SDIget_var(handle, sdsid);
-    if(var == NULL)
+    if (var == NULL)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* If this variable doesn't have a valid NDG ref, we cannot proceed */
@@ -571,8 +541,7 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
     if (status == FAIL)
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
-    if (att_tag != 0 && att_ref != 0)
-    {
+    if (att_tag != 0 && att_ref != 0) {
         /* Get offset/length of the attribute values. */
         off = Hoffset(handle->hdf_file, att_tag, att_ref);
         if (off == FAIL)
@@ -588,23 +557,21 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
          of the dimensions' LUFs.
          Otherwise, return "off" and "len" for the inquired attribute. */
 
-        if (att_tag != DFTAG_SDL && att_tag != DFTAG_SDU && att_tag != DFTAG_SDF)
-        {
+        if (att_tag != DFTAG_SDL && att_tag != DFTAG_SDU && att_tag != DFTAG_SDF) {
             *offset = off;
             *length = len;
             HGOTO_DONE(1);
         }
 
-        if (len == 0)
-        {
+        if (len == 0) {
             HGOTO_DONE(0);
         }
 
         /* Read the luf string */
-        lufbuf = (char *)HDmalloc(len+1);
+        lufbuf = malloc(len + 1);
         if (lufbuf == NULL)
             HGOTO_ERROR(DFE_NOSPACE, FAIL);
-        Hgetelement(handle->hdf_file, att_tag, att_ref, lufbuf);
+        Hgetelement(handle->hdf_file, att_tag, att_ref, (uint8 *)lufbuf);
 
         /*
          * Parse the luf string to obtain the offset/length of the requested luf
@@ -617,17 +584,15 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
 
         /* If data set's attribute is being inquired, then return with offset
          and length of the SDS' attribute's data only */
-        if (!isdim)
-        {
+        if (!isdim) {
             *offset = off;
             *length = sdsluf_len;
         }
 
         /* If a dimension's attribute is being inquired, then continue parsing
          the attribute string to get the appropriate dimension's attribute */
-        else
-        {
-            char *dim_att=NULL; /* to hold a dimension's attribute */
+        else {
+            char *dim_att = NULL; /* to hold a dimension's attribute */
 
             /* Move cursor forward to the first dimension's attribute */
             lufp += sdsluf_len + 1;
@@ -644,8 +609,7 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
 
             /* Walk through each dimension to find requested luf */
             offp = 0; /* offset pointer */
-            for (ii = 0; ii <= dimidx_invar; ii++)
-            {
+            for (ii = 0; ii <= dimidx_invar; ii++) {
                 /* NOTE: Should make tests for all cases to make sure all
                      empty attributes are covered -BMR */
 
@@ -653,32 +617,28 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
                 if (HDstrlen(lufp) == 0)
                     dim_att_len = 0;
                 /* If dimension has attribute, calculate its attr length */
-                else
-                {
-                    dim_att = (char *)HDmalloc(HDstrlen(lufp) + 1);
+                else {
+                    dim_att = malloc(HDstrlen(lufp) + 1);
                     if (dim_att == NULL)
                         HGOTO_ERROR(DFE_NOSPACE, FAIL);
 
                     /* Extract current dimension's attribute */
-                    HDstrcpy(dim_att, (char *) lufp);
+                    HDstrcpy(dim_att, (char *)lufp);
                     dim_att[HDstrlen(lufp)] = 0;
-                    dim_att_len = HDstrlen(dim_att);
+                    dim_att_len             = HDstrlen(dim_att);
                 }
 
                 /* Move forward if this is not the dim we're looking for */
-                if (ii != dimidx_invar)
-                {
+                if (ii != dimidx_invar) {
                     /* move cursor forward to the next dimension's attribute */
-                    lufp += dim_att_len + 1;  /* <- 1 is for the NULL */
+                    lufp += dim_att_len + 1; /* <- 1 is for the NULL */
 
                     /* add the length to the offset so far */
                     offp += dim_att_len + 1;
                 }
-                if (dim_att != NULL)
-                {
-                    HDfree(dim_att);
-                    dim_att = NULL;
-                }
+
+                free(dim_att);
+                dim_att = NULL;
             }
 
             /* Calculate offset and length of the requested dimension's luf   */
@@ -691,19 +651,16 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
         }
         ret_value = 1;
     }
-    if (lufbuf) HDfree(lufbuf);
+    free(lufbuf);
 
-    done:
-    if (ret_value == FAIL)
-    { /* Failure cleanup */
-        if (lufbuf) HDfree(lufbuf);
+done:
+    if (ret_value == FAIL) { /* Failure cleanup */
+        free(lufbuf);
     }
-    /* Normal cleanup */
 
     return ret_value;
 } /* SDgetoldattdatainfo */
 
-
 /******************************************************************************
  NAME
     SDgetanndatainfo -- Retrieves location and size of annotations' data.
@@ -735,23 +692,20 @@ SDgetoldattdatainfo(int32 dim_id, int32 sdsid, char  *attr_name,
     -BMR 2011/1/9
 
  ******************************************************************************/
-intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offsetarray, int32* lengtharray)
+intn
+SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32 *offsetarray, int32 *lengtharray)
 {
-    CONSTR(FUNC, "SDgetanndatainfo");
-    int32   file_id=FAIL,  /* file, AN API, annotation IDs */
-            an_id=FAIL,
-            ann_id=FAIL;
-    NC     *handle = NULL;  /* file structure */
-    NC_var *var = NULL;    /* variable structure of sds, to get NDG ref */
-    int32  *dannots = NULL,  /* list of data annotation IDs */
-            n_flabels = 0,  /* number of file labels */
-            n_fdescs = 0,  /* number of file descriptions */
-            n_dlabels = 0,  /* number of object labels */
-            n_ddescs = 0;  /* number of file descriptions */
-    uint16  elem_tag, elem_ref; /* tag/ref of dataset's NDG */
-    intn    num_annots,    /* number of annotation of requested type */
-    ii,
-    ret_value = 0;
+    int32 file_id = FAIL, /* file, AN API, annotation IDs */
+        an_id = FAIL, ann_id = FAIL;
+    NC    *handle  = NULL;     /* file structure */
+    int32 *dannots = NULL,     /* list of data annotation IDs */
+        n_flabels  = 0,        /* number of file labels */
+        n_fdescs   = 0,        /* number of file descriptions */
+        n_dlabels  = 0,        /* number of object labels */
+        n_ddescs   = 0;        /* number of file descriptions */
+    uint16 elem_tag, elem_ref; /* tag/ref of dataset's NDG */
+    intn   num_annots = -1,    /* number of annotation of requested type */
+        ii, ret_value = 0;
 
     /* Clear error stack */
     HEclear();
@@ -761,17 +715,15 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* Getting only offsets or lengths is not allowed */
-    if ((offsetarray != NULL && lengtharray == NULL) ||
-            (offsetarray == NULL && lengtharray != NULL))
+    if ((offsetarray != NULL && lengtharray == NULL) || (offsetarray == NULL && lengtharray != NULL))
         HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* Check if the given id is a file id */
     handle = SDIhandle_from_id(sdsid, CDFTYPE);
 
     /* It is a file id, process its annotations appropriately */
-    if (handle != NULL)
-    {
-        /* Open file to start Annotation inteface */
+    if (handle != NULL) {
+        /* Open file to start Annotation interface */
         if ((file_id = Hopen(handle->path, DFACC_READ, 0)) == FAIL)
             HGOTO_ERROR(DFE_BADOPEN, FAIL);
         if ((an_id = ANstart(file_id)) == FAIL)
@@ -803,8 +755,7 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
             num_annots = size;
 
         /* Get offset/length of each annotation of the specified type */
-        for (ii = 0; ii < num_annots; ii++)
-        {
+        for (ii = 0; ii < num_annots; ii++) {
             intn status;
 
             /* Get access to an annotation of the specified type */
@@ -825,12 +776,10 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
         }
     }
     /* Not a file ID */
-    else
-    {
+    else {
         /* Check if the given dataset ID really is a dataset ID */
         handle = SDIhandle_from_id(sdsid, SDSTYPE);
-        if(handle != NULL)
-        {
+        if (handle != NULL) {
             /* Validate annotation type */
             if (annot_type != AN_DATA_LABEL && annot_type != AN_DATA_DESC)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
@@ -843,7 +792,7 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
             if (elem_ref <= 0)
                 HGOTO_ERROR(DFE_ARGS, FAIL);
 
-            /* Open file to start Annotation inteface */
+            /* Open file to start Annotation interface */
             if ((file_id = Hopen(handle->path, DFACC_READ, 0)) == FAIL)
                 HGOTO_ERROR(DFE_BADOPEN, FAIL);
             if ((an_id = ANstart(file_id)) == FAIL)
@@ -853,15 +802,15 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
             num_annots = ANnumann(an_id, annot_type, elem_tag, elem_ref);
             if (num_annots == FAIL)
                 HGOTO_ERROR(DFE_INTERNAL, FAIL)
-                else if (num_annots == 0) /* then try SDG */
-                {
-                    elem_tag = DFTAG_SDG;
-                    num_annots = ANnumann(an_id, annot_type, elem_tag, elem_ref);
+            else if (num_annots == 0) /* then try SDG */
+            {
+                elem_tag   = DFTAG_SDG;
+                num_annots = ANnumann(an_id, annot_type, elem_tag, elem_ref);
 
-                    /* If there are no SDG annotations either then return 0 */
-                    if (num_annots == 0)
-                        HGOTO_DONE(0);
-                }
+                /* If there are no SDG annotations either then return 0 */
+                if (num_annots == 0)
+                    HGOTO_DONE(0);
+            }
 
             /* If offsets/lengths are not desired, return the number of annots */
             if (offsetarray == NULL || lengtharray == NULL)
@@ -872,7 +821,7 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
                 num_annots = size;
 
             /* Allocate space for list of annotation IDs on this tag/ref */
-            if ((dannots = (int32 *)HDmalloc(num_annots * sizeof(int32))) == NULL)
+            if ((dannots = malloc(num_annots * sizeof(int32))) == NULL)
                 HGOTO_ERROR(DFE_NOSPACE, FAIL);
 
             /* Get list of annotations IDs on this tag/ref */
@@ -882,32 +831,26 @@ intn SDgetanndatainfo(int32 sdsid, ann_type annot_type, uintn size, int32* offse
     I'm not sure.  MFAN needs to take care of them if not. -BMR */
 
             /* Loop through the annotation list and get their offsets/lengths */
-            for (ii = 0; ii < num_annots; ii++)
-            {
+            for (ii = 0; ii < num_annots; ii++) {
                 /* Get annotation's offset and length */
                 ret_value = ANgetdatainfo(dannots[ii], &offsetarray[ii], &lengtharray[ii]);
                 if (ret_value == FAIL)
                     HGOTO_ERROR(DFE_INTERNAL, FAIL);
             }
         } /* ID is an SDS */
-    } /* Not a file ID */
+    }     /* Not a file ID */
 
     /* Return the number of annotations retrieved */
     ret_value = num_annots;
 
-    done:
-    if (ret_value == FAIL)
-    { /* Failure cleanup */
-    }
-    /* Normal cleanup */
-
+done:
     /* Release allocated memory */
-    if (dannots) HDfree(dannots);
+    free(dannots);
 
     /* Terminate access to the AN API and close the file if they are opened */
-    if(an_id != FAIL)
+    if (an_id != FAIL)
         ANend(an_id);
-    if(file_id != FAIL)
+    if (file_id != FAIL)
         Hclose(file_id);
 
     return ret_value;
