@@ -1,7 +1,6 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Id$
  *********************************************************************/
 
 #include "h4config.h"
@@ -15,46 +14,29 @@
 
 /* #define MDEBUG 1 */
 
-  /*
-   * Test driver for netCDF implementation.  This program performs
-   * tests against the netCDF specification for all user-level
-   * functions in an implementation of the netCDF library.  Must be
-   * invoked from a directory in which the invoker has write
-   * permission.
-   */
+/*
+ * Test driver for netCDF implementation.  This program performs
+ * tests against the netCDF specification for all user-level
+ * functions in an implementation of the netCDF library.  Must be
+ * invoked from a directory in which the invoker has write
+ * permission.
+ */
 
 #include <stdio.h>
-#if defined TEST_PC || defined TEST_WIN
-FILE *dbg_file;
-#endif
 
 #include <stdlib.h>
 #include <string.h> /* to remove warnings, HDFFR-1434 */
 
-#ifdef PROTOTYPE
-int main(int argc, char *argv[])
-#else
-int main(argc, argv)
-int argc;
-char *argv[];
-#endif
+int
+main(void)
 {
-    static char testfile[] = "test.nc";
+    static char testfile[]            = "test.nc";
     static char unlim_testfile_name[] = "test_unlim.nc";
-    int status = 0;
 
-#if defined TEST_PC || defined TEST_WIN
-    dbg_file=fopen("test.dbg","w+");
-#endif
-
-#ifdef MDEBUG
-    malloc_debug(2);
-#endif /* MDEBUG */
-
-    ncopts &= ~NC_FATAL;	/* make errors nonfatal */
-    ncopts &= ~NC_VERBOSE;	/* turn off error messages */
-    ncopts |= NC_VERBOSE;	/* turn  error messages on--AKC */
-    ncopts &= ~NC_VERBOSE;	/* turn off error messages */
+    ncopts &= ~NC_FATAL;   /* make errors nonfatal */
+    ncopts &= ~NC_VERBOSE; /* turn off error messages */
+    ncopts |= NC_VERBOSE;  /* turn  error messages on--AKC */
+    ncopts &= ~NC_VERBOSE; /* turn off error messages */
 
     test_nccreate(testfile);
 
@@ -124,10 +106,5 @@ char *argv[];
 
     test_nctypelen();
 
-#if defined TEST_PC || defined TEST_WIN
-    fclose(dbg_file);
-#endif
-#define EXIT_SUCCESS 0
     return EXIT_SUCCESS;
 }
-
