@@ -20,12 +20,12 @@
  *	  test_chunked_partial - tests on chunked and partially written SDS
  *	  test_chkcmp_SDSs     - tests chunked/compressed SDSs
  *	  test_extend_SDSs     - tests SDSs with unlimited dimensions
- *    check_datasizes - utility routine that calls SDgetdatasize and verifies 
+ *    check_datasizes - utility routine that calls SDgetdatasize and verifies
  *		the retrieved data sizes.
  * NOTE: At this time, SDgetdatasize will not return the correct compressed
  *	size unless SDreaddata or SDendaccess is called between SDwritedata
  *	and SDgetdatasize.
-****************************************************************************/
+ ****************************************************************************/
 
 #include "mfhdf.h"
 
@@ -33,25 +33,25 @@
 
 #include "hdftest.h"
 
-#define FILE_NAME     "datasizes.hdf"	/* data file to test empty SDSs */
-#define X_LENGTH      10
-#define Y_LENGTH      10
-#define RANK          2
+#define FILE_NAME "datasizes.hdf" /* data file to test empty SDSs */
+#define X_LENGTH  10
+#define Y_LENGTH  10
+#define RANK      2
 
 /* Utility routine that selects that named SDS, then calls SDgetdatasize
  * and verifies the returned values. */
-static void check_datasizes(
-		int32 fid, 		/* file id */
-		char* sds_name, 	/* name of the inquired SDS */
-		int32 comp_size_check, 	/* expected compressed data size */
-		int32 uncomp_size_check,/* expected non-compressed data size */
-		int* ret_num_errs	/* current number of errors */ )
+static void
+check_datasizes(int32       fid,               /* file id */
+                const char *sds_name,          /* name of the inquired SDS */
+                int32       comp_size_check,   /* expected compressed data size */
+                int32       uncomp_size_check, /* expected non-compressed data size */
+                int        *ret_num_errs /* current number of errors */)
 {
     int32 sds_id, sds_index;
-    intn status;
-    int num_errs = 0;
-    char mesg[80];
-    int32 uncomp_size=0, comp_size=0;
+    intn  status;
+    int   num_errs = 0;
+    char  mesg[80];
+    int32 uncomp_size = 0, comp_size = 0;
 
     /* Get index of dataset using its name */
     sds_index = SDnametoindex(fid, sds_name);
@@ -62,7 +62,7 @@ static void check_datasizes(
     sds_id = SDselect(fid, sds_index);
     CHECK(sds_id, FAIL, "check_datasizes: SDselect");
 
-    /* The retrieved values from SDgetdatasize are verified against 
+    /* The retrieved values from SDgetdatasize are verified against
        'comp_size_check' and 'uncomp_size_check' */
     status = SDgetdatasize(sds_id, &comp_size, &uncomp_size);
     sprintf(mesg, "SDgetdatasize: SDS named (%s)", sds_name);
@@ -75,19 +75,20 @@ static void check_datasizes(
     CHECK(status, FAIL, "check_datasizes: SDendaccess");
 
     *ret_num_errs = num_errs;
-}   /* check_datasizes */
+} /* check_datasizes */
 
 /* Test non-special SDSs.  This routine creates non-special SDSs, writes
  * data to one of the SDSs, and checks the sizes returned by SDgetdatasize
  */
-static intn test_nonspecial_SDSs(int32 fid)
+static intn
+test_nonspecial_SDSs(int32 fid)
 {
     int32 sds_id;
     int32 dimsize[2], start[2], edges[2];
     int32 data[Y_LENGTH][X_LENGTH];
     intn  status;
     int   i, j;
-    int   num_errs = 0;		/* number of errors so far */
+    int   num_errs = 0; /* number of errors so far */
 
     /* Initialize data for the dataset */
     for (j = 0; j < Y_LENGTH; j++) {
@@ -98,7 +99,7 @@ static intn test_nonspecial_SDSs(int32 fid)
     /* Create a 2x2 dataset called "EmptyDataset" */
     dimsize[0] = Y_LENGTH;
     dimsize[1] = X_LENGTH;
-    sds_id = SDcreate(fid, "EmptyDataset", DFNT_FLOAT32, 2, dimsize);
+    sds_id     = SDcreate(fid, "EmptyDataset", DFNT_FLOAT32, 2, dimsize);
     CHECK(sds_id, FAIL, "test_nonspecial_SDSs: SDcreate 'EmptyDataset'");
 
     /* Close this SDS */
@@ -119,7 +120,7 @@ static intn test_nonspecial_SDSs(int32 fid)
     edges[1] = X_LENGTH;
 
     /* Write the stored data to the dataset */
-    status = SDwritedata(sds_id, start, NULL, edges, (VOIDP)data);
+    status = SDwritedata(sds_id, start, NULL, edges, (void *)data);
     CHECK(sds_id, FAIL, "test_nonspecial_SDSs: SDwritedata");
 
     /* Close this SDS */
@@ -127,7 +128,8 @@ static intn test_nonspecial_SDSs(int32 fid)
     CHECK(status, FAIL, "test_nonspecial_SDSs: SDendaccess");
 
     /* Check the size of the data of this SDS */
-    check_datasizes(fid, "WrittenDataset", Y_LENGTH*X_LENGTH*SIZE_INT32, Y_LENGTH*X_LENGTH*SIZE_INT32, &num_errs);
+    check_datasizes(fid, "WrittenDataset", Y_LENGTH * X_LENGTH * SIZE_INT32, Y_LENGTH * X_LENGTH * SIZE_INT32,
+                    &num_errs);
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
@@ -137,22 +139,22 @@ static intn test_nonspecial_SDSs(int32 fid)
  * and writes to "CompressedData" and "Non-CompressedData" SDSs.  It will then
  * check the sizes returned from SDgetdatasize calls.
  */
-static intn test_compressed_SDSs(int32 fid)
+static intn
+test_compressed_SDSs(int32 fid)
 {
-    int32     sds_id, esds_id, usds_id;
-    int32     start[2], edges[2], dim_sizes[2];
-    comp_coder_t comp_type;    /* Compression flag */
-    comp_info c_info;	   /* Compression structure */
-    int32     data[Y_LENGTH][X_LENGTH];
-    intn      status;
-    int       i, j;
-    int   num_errs = 0;   /* number of errors so far */
+    int32        sds_id, esds_id, usds_id;
+    int32        start[2], edges[2], dim_sizes[2];
+    comp_coder_t comp_type; /* Compression flag */
+    comp_info    c_info;    /* Compression structure */
+    int32        data[Y_LENGTH][X_LENGTH];
+    intn         status;
+    int          i, j;
+    int          num_errs = 0; /* number of errors so far */
 
     /* Buffer array data and define array dimensions */
-    for (j = 0; j < Y_LENGTH; j++)
-    {
+    for (j = 0; j < Y_LENGTH; j++) {
         for (i = 0; i < X_LENGTH; i++)
-                data[j][i] = (i + j) + 1;
+            data[j][i] = (i + j) + 1;
     }
     dim_sizes[0] = Y_LENGTH;
     dim_sizes[1] = X_LENGTH;
@@ -167,9 +169,9 @@ static intn test_compressed_SDSs(int32 fid)
     usds_id = SDcreate(fid, "Non-CompressedData", DFNT_INT32, RANK, dim_sizes);
     CHECK(usds_id, FAIL, "test_compressed_SDSs: SDcreate 'Non-CompressedData'");
 
-    comp_type = COMP_CODE_DEFLATE;
+    comp_type            = COMP_CODE_DEFLATE;
     c_info.deflate.level = 6;
-    status = SDsetcompress(sds_id, comp_type, &c_info);
+    status               = SDsetcompress(sds_id, comp_type, &c_info);
     CHECK(status, FAIL, "test_compressed_SDSs: SDsetcompress 'CompressedData'");
 
     status = SDsetcompress(esds_id, comp_type, &c_info);
@@ -182,14 +184,14 @@ static intn test_compressed_SDSs(int32 fid)
     edges[1] = X_LENGTH;
 
     /* Write the stored data to the compressed dataset */
-    status = SDwritedata(sds_id, start, NULL, edges, (VOIDP)data);
+    status = SDwritedata(sds_id, start, NULL, edges, (void *)data);
     CHECK(status, FAIL, "test_compressed_SDSs: SDwritedata");
- 
+
     /* Write the stored data to the dataset non-compressed dataset */
-    status = SDwritedata(usds_id, start, NULL, edges, (VOIDP)data);
+    status = SDwritedata(usds_id, start, NULL, edges, (void *)data);
     CHECK(status, FAIL, "test_compressed_SDSs: SDwritedata");
- 
-     /* Close the SDSs */
+
+    /* Close the SDSs */
     status = SDendaccess(sds_id);
     CHECK(status, FAIL, "test_compressed_SDSs: SDendaccess 'CompressedData'");
 
@@ -200,13 +202,14 @@ static intn test_compressed_SDSs(int32 fid)
     CHECK(status, FAIL, "test_compressed_SDSs: SDendaccess 'Non-CompressedData'");
 
     /* Check the size of the data of this SDS - 59 is from examining previously */
-    check_datasizes(fid, "CompressedData", 59, Y_LENGTH*X_LENGTH*SIZE_INT32, &num_errs);
+    check_datasizes(fid, "CompressedData", 59, Y_LENGTH * X_LENGTH * SIZE_INT32, &num_errs);
 
     /* Check the size of the data of this SDS */
     check_datasizes(fid, "Compressed-No-Data", 0, 0, &num_errs);
 
     /* Check the size of the data of this SDS */
-    check_datasizes(fid, "Non-CompressedData", Y_LENGTH*X_LENGTH*SIZE_INT32, Y_LENGTH*X_LENGTH*SIZE_INT32, &num_errs);
+    check_datasizes(fid, "Non-CompressedData", Y_LENGTH * X_LENGTH * SIZE_INT32,
+                    Y_LENGTH * X_LENGTH * SIZE_INT32, &num_errs);
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
@@ -217,19 +220,20 @@ static intn test_compressed_SDSs(int32 fid)
  * don't have data.
  */
 
-#define X_LENGTH2  4
-#define Y_LENGTH2  9
-#define CHK_X      3
-#define CHK_Y      2
+#define X_LENGTH2 4
+#define Y_LENGTH2 9
+#define CHK_X     3
+#define CHK_Y     2
 
-static intn test_empty_SDSs(int32 fid)
+static intn
+test_empty_SDSs(int32 fid)
 {
     int32         ch_sds_id, chcp_sds_id;
     int32         dim_sizes[RANK];
-    HDF_CHUNK_DEF c_def; /* Chunking definitions */ 
+    HDF_CHUNK_DEF c_def; /* Chunking definitions */
     int32         flag;
     intn          status;
-    int           num_errs = 0;   /* number of errors so far */
+    int           num_errs = 0; /* number of errors so far */
 
     c_def.chunk_lengths[0] = CHK_X;
     c_def.chunk_lengths[1] = CHK_Y;
@@ -237,22 +241,22 @@ static intn test_empty_SDSs(int32 fid)
     /* Create Y_LENGTH2 x X_LENGTH2 empty chunked and chunked/compressed SDSs */
     dim_sizes[0] = Y_LENGTH2;
     dim_sizes[1] = X_LENGTH2;
-    ch_sds_id = SDcreate(fid, "Chunked Empty", DFNT_INT16, RANK, dim_sizes);
+    ch_sds_id    = SDcreate(fid, "Chunked Empty", DFNT_INT16, RANK, dim_sizes);
     CHECK(ch_sds_id, FAIL, "test_empty_SDSs: SDcreate 'Chunked Empty'");
 
     chcp_sds_id = SDcreate(fid, "Chunked Compressed Empty", DFNT_INT16, RANK, dim_sizes);
     CHECK(chcp_sds_id, FAIL, "test_empty_SDSs: SDcreate 'Chunked Compressed Empty'");
 
     /* Set info for chunking */
-    flag = HDF_CHUNK;
+    flag   = HDF_CHUNK;
     status = SDsetchunk(ch_sds_id, c_def, flag);
     CHECK(status, FAIL, "test_empty_SDSs: SDsetchunk");
 
     /* Set info for chunking and compression */
-    flag = HDF_CHUNK | HDF_COMP;
-    c_def.comp.comp_type = COMP_CODE_DEFLATE;
+    flag                           = HDF_CHUNK | HDF_COMP;
+    c_def.comp.comp_type           = COMP_CODE_DEFLATE;
     c_def.comp.cinfo.deflate.level = 6;
-    status = SDsetchunk(chcp_sds_id, c_def, flag);
+    status                         = SDsetchunk(chcp_sds_id, c_def, flag);
     CHECK(status, FAIL, "test_empty_SDSs: SDsetchunk");
 
     /* Terminate access to the datasets */
@@ -271,46 +275,43 @@ static intn test_empty_SDSs(int32 fid)
     return num_errs;
 } /* test_empty_SDSs */
 
-/* Test with chunked and partially written SDS.  This routine creates a 
+/* Test with chunked and partially written SDS.  This routine creates a
  * "Chunked Not Empty" SDS and writes some chunks but not all to it.  It will
  * then call SDgetdatasize to verify the sizes.
  */
-static intn test_chunked_partial(int32 fid)
+static intn
+test_chunked_partial(int32 fid)
 {
-    int32         sds_id, sds_index;
+    int32         sds_id;
     int32         dim_sizes[RANK], origin[RANK];
-    HDF_CHUNK_DEF c_def; /* Chunking definitions */ 
-    int32         flag; /* Chunking flag */
-    int16         fill_value = 0;   /* Fill value */
+    HDF_CHUNK_DEF c_def;          /* Chunking definitions */
+    int32         flag;           /* Chunking flag */
+    int16         fill_value = 0; /* Fill value */
     intn          status;
-    int           num_errs = 0;   /* number of errors so far */
+    int           num_errs = 0; /* number of errors so far */
 
     /* Declare chunks data type and initialize some of them. */
-    int16 chunk1[CHK_X][CHK_Y] = { {1, 1},
-                           {1, 1},
-                           {1, 1} }; 
+    int16 chunk1[CHK_X][CHK_Y] = {{1, 1}, {1, 1}, {1, 1}};
 
-    int16 chunk3[CHK_X][CHK_Y] = { {3, 3},
-                           {3, 3},
-                           {3, 3} }; 
+    int16 chunk3[CHK_X][CHK_Y] = {{3, 3}, {3, 3}, {3, 3}};
 
     /* Initialize chunk size */
-    HDmemset(&c_def, 0, sizeof(c_def)) ;
+    memset(&c_def, 0, sizeof(c_def));
     c_def.chunk_lengths[0] = CHK_X;
     c_def.chunk_lengths[1] = CHK_Y;
 
     /* Create Y_LENGTH2 x X_LENGTH2 SDS */
     dim_sizes[0] = X_LENGTH2;
     dim_sizes[1] = Y_LENGTH2;
-    sds_id = SDcreate(fid, "Chunked Not Empty", DFNT_INT16, RANK, dim_sizes);
+    sds_id       = SDcreate(fid, "Chunked Not Empty", DFNT_INT16, RANK, dim_sizes);
     CHECK(sds_id, FAIL, "test_chunked_partial: SDcreate 'Chunked Not Empty'");
 
     /* Fill the SDS array with the fill value */
-    status = SDsetfillvalue(sds_id, (VOIDP)&fill_value);
+    status = SDsetfillvalue(sds_id, (void *)&fill_value);
     CHECK(status, FAIL, "test_chunked_partial: SDsetfillvalue");
 
     /* Set info for chunking */
-    flag = HDF_CHUNK;
+    flag   = HDF_CHUNK;
     status = SDsetchunk(sds_id, c_def, flag);
     CHECK(status, FAIL, "test_chunked_partial: SDsetchunk");
 
@@ -319,13 +320,13 @@ static intn test_chunked_partial(int32 fid)
     /* Write the chunk with the coordinates (0,0) */
     origin[0] = 0;
     origin[1] = 0;
-    status = SDwritechunk(sds_id, origin, (VOIDP) chunk1);
+    status    = SDwritechunk(sds_id, origin, (void *)chunk1);
     CHECK(status, FAIL, "test_chunked_partial: SDwritechunk");
 
     /* Write the chunk with the coordinates (1,0) */
     origin[0] = 1;
     origin[1] = 0;
-    status = SDwritechunk(sds_id, origin, (VOIDP) chunk3);
+    status    = SDwritechunk(sds_id, origin, (void *)chunk3);
     CHECK(status, FAIL, "test_chunked_partial: SDwritechunk");
 
     /* Terminate access to the "Chunked Not Empty" dataset */
@@ -335,82 +336,78 @@ static intn test_chunked_partial(int32 fid)
     /* Check the size of the data of this SDS - only chunked, not compressed,
        so both values should be the same; there are two chunks of size
        CHK_X*CHK_Y in type int16 written */
-    check_datasizes(fid, "Chunked Not Empty", CHK_X*CHK_Y*SIZE_INT16*2, CHK_X*CHK_Y*SIZE_INT16*2, &num_errs);
+    check_datasizes(fid, "Chunked Not Empty", CHK_X * CHK_Y * SIZE_INT16 * 2, CHK_X * CHK_Y * SIZE_INT16 * 2,
+                    &num_errs);
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
 } /* test_chunked_partial */
 
-/* Test with chunked and compressed SDS.  This routine creates 
+/* Test with chunked and compressed SDS.  This routine creates
  * "ChunkedDeflateData" and "ChunkedNoDeflateData" SDSs and writes the same
  * data to both.  It will then use SDgetdatasize to verify the sizes.
  */
-static intn test_chkcmp_SDSs(int32 fid)
+static intn
+test_chkcmp_SDSs(int32 fid)
 {
     int32         sds_id, sds_index;
     int32         cmpsds_id, cmpsds_index;
     int32         flag, maxcache, new_maxcache;
     int32         dim_sizes[RANK], origin[RANK];
-    HDF_CHUNK_DEF c_def; /* Chunking definitions */ 
-    int32         fill_value = 0;   /* Fill value */
-    int32	  comp_size1=0, uncomp_size1=0;
-    int32	  comp_size2=0, uncomp_size2=0;
+    HDF_CHUNK_DEF c_def;          /* Chunking definitions */
+    int32         fill_value = 0; /* Fill value */
+    int32         comp_size1 = 0, uncomp_size1 = 0;
+    int32         comp_size2 = 0, uncomp_size2 = 0;
     intn          status;
-    int           num_errs = 0;   /* number of errors so far */
+    int           num_errs = 0; /* number of errors so far */
 
     /* Declare chunks data type and initialize some of them. */
-    int16 chunk1[CHK_X][CHK_Y] = { {1, 1},
-                           {1, 1},
-                           {1, 1} }; 
+    int32 chunk1[CHK_X][CHK_Y] = {{1, 1}, {1, 1}, {1, 1}};
 
-    int16 chunk3[CHK_X][CHK_Y] = { {3, 3},
-                           {3, 3},
-                           {3, 3} }; 
+    int32 chunk3[CHK_X][CHK_Y] = {{3, 3}, {3, 3}, {3, 3}};
 
-    int32 chunk2[CHK_X][CHK_Y] = { {2, 2},
-                           {2, 2},
-                           {2, 2} }; 
+    int32 chunk2[CHK_X][CHK_Y] = {{2, 2}, {2, 2}, {2, 2}};
 
     /* Initialize chunk size */
-    HDmemset(&c_def, 0, sizeof(c_def)) ;
+    memset(&c_def, 0, sizeof(c_def));
     c_def.chunk_lengths[0] = CHK_X;
     c_def.chunk_lengths[1] = CHK_Y;
 
     /* Create Y_LENGTH2 x X_LENGTH2 SDS */
     dim_sizes[0] = Y_LENGTH2;
     dim_sizes[1] = X_LENGTH2;
-    cmpsds_id = SDcreate(fid, "ChunkedDeflateData", DFNT_INT32, RANK, dim_sizes);
+    cmpsds_id    = SDcreate(fid, "ChunkedDeflateData", DFNT_INT32, RANK, dim_sizes);
     CHECK(cmpsds_id, FAIL, "test_chkcmp_SDSs: SDcreate 'ChunkedDeflateData'");
 
     sds_id = SDcreate(fid, "ChunkedNoDeflateData", DFNT_INT32, RANK, dim_sizes);
     CHECK(sds_id, FAIL, "test_chkcmp_SDSs: SDcreate 'ChunkedNoDeflateData'");
 
     /* Fill the SDS array with the fill value */
-    status = SDsetfillvalue(cmpsds_id, (VOIDP)&fill_value);
+    status = SDsetfillvalue(cmpsds_id, (void *)&fill_value);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDsetfillvalue 'ChunkedDeflateData'");
 
-    status = SDsetfillvalue(sds_id, (VOIDP)&fill_value);
+    status = SDsetfillvalue(sds_id, (void *)&fill_value);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDsetfillvalue 'ChunkedNoDeflateData'");
 
     /* Set info for chunking and compression */
-    flag = HDF_CHUNK | HDF_COMP;
-    c_def.comp.comp_type = COMP_CODE_DEFLATE;
+    flag                           = HDF_CHUNK | HDF_COMP;
+    c_def.comp.comp_type           = COMP_CODE_DEFLATE;
     c_def.comp.cinfo.deflate.level = 6;
-    status = SDsetchunk(cmpsds_id, c_def, flag);
+    status                         = SDsetchunk(cmpsds_id, c_def, flag);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDsetchunk 'ChunkedDeflateData'");
 
     /* Set info for chunking and compression */
-    HDmemset(&c_def, 0, sizeof(c_def)) ;
+    memset(&c_def, 0, sizeof(c_def));
     c_def.chunk_lengths[0] = CHK_X;
     c_def.chunk_lengths[1] = CHK_Y;
 
-    flag = HDF_CHUNK;
+    flag   = HDF_CHUNK;
     status = SDsetchunk(sds_id, c_def, flag);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDsetchunk 'ChunkedNoDeflateData'");
 
     /* Set chunk cache to hold maximum of 3 chunks */
-    maxcache = 3;
-    flag = 0;
+    maxcache     = 3;
+    flag         = 0;
     new_maxcache = SDsetchunkcache(cmpsds_id, maxcache, flag);
     CHECK(new_maxcache, FAIL, "test_chkcmp_SDSs: SDsetchunkcache 'ChunkedDeflateData'");
 
@@ -447,25 +444,25 @@ static intn test_chkcmp_SDSs(int32 fid)
     /* Write the chunk with the coordinates (0,0) */
     origin[0] = 0;
     origin[1] = 0;
-    status = SDwritechunk(cmpsds_id, origin, (VOIDP) chunk1);
+    status    = SDwritechunk(cmpsds_id, origin, (void *)chunk1);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDwritechunk 'ChunkedDeflateData'");
-    status = SDwritechunk(sds_id, origin, (VOIDP) chunk1);
+    status = SDwritechunk(sds_id, origin, (void *)chunk1);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDwritechunk 'ChunkedNoDeflateData'");
 
     /* Write the chunk with the coordinates (1,0) */
     origin[0] = 1;
     origin[1] = 0;
-    status = SDwritechunk(cmpsds_id, origin, (VOIDP) chunk3);
+    status    = SDwritechunk(cmpsds_id, origin, (void *)chunk3);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDwritechunk 'ChunkedDeflateData'");
-    status = SDwritechunk(sds_id, origin, (VOIDP) chunk3);
+    status = SDwritechunk(sds_id, origin, (void *)chunk3);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDwritechunk 'ChunkedNoDeflateData'");
 
     /* Write the chunk with the coordinates (0,1) */
     origin[0] = 0;
     origin[1] = 1;
-    status = SDwritechunk(cmpsds_id, origin, (VOIDP) chunk2);
+    status    = SDwritechunk(cmpsds_id, origin, (void *)chunk2);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDwritechunk 'ChunkedDeflateData'");
-    status = SDwritechunk(sds_id, origin, (VOIDP) chunk2);
+    status = SDwritechunk(sds_id, origin, (void *)chunk2);
     CHECK(status, FAIL, "test_chkcmp_SDSs: SDwritechunk 'ChunkedNoDeflateData'");
 
     /* Terminate access to the datasets */
@@ -497,11 +494,12 @@ static intn test_chkcmp_SDSs(int32 fid)
 
     /* In this test, compressed data size should be smaller than non-compressed
        data size */
-    if (comp_size1 >= uncomp_size1)
-    {
-	printf("*** Routine test_chkcmp_SDSs: FAILED at line %d ***\n", __LINE__);
-	printf("    In this test, compressed data size (%d) should be smaller than non-compressed data size (%d)\n", comp_size1, uncomp_size1);
-	num_errs++;
+    if (comp_size1 >= uncomp_size1) {
+        printf("*** Routine test_chkcmp_SDSs: FAILED at line %d ***\n", __LINE__);
+        printf("    In this test, compressed data size (%d) should be smaller than non-compressed data size "
+               "(%d)\n",
+               comp_size1, uncomp_size1);
+        num_errs++;
     }
 
     /* Terminate access to the data sets. */
@@ -516,20 +514,24 @@ static intn test_chkcmp_SDSs(int32 fid)
 } /* test_chkcmp_SDSs */
 
 /* Test SDSs with unlimited dimensions.  This routine creates SDSs with
-   unlimited dimensions, writes data to it, and checks the sizes returned 
+   unlimited dimensions, writes data to it, and checks the sizes returned
    by SDgetdatasize
  */
-static intn test_extend_SDSs(int32 fid)
+static intn
+test_extend_SDSs(int32 fid)
 {
-    int32 sds_id, sds_index;
-    int32 dimsize[2], start[2], edges[2];
-    int32 dimsize1[1], start1[1], edges1[1];
+    int32 sds_id     = -1;
+    int32 dimsize[2] = {-1, -1};
+    int32 start[2]   = {-1, -1};
+    int32 edges[2]   = {-1, -1};
+    int32 start1[1]  = {-1};
+    int32 edges1[1]  = {-1};
     int32 data[Y_LENGTH][X_LENGTH];
     float fdata[Y_LENGTH];
     int32 output[Y_LENGTH][X_LENGTH];
-    intn  status;
+    intn  status = -1;
     int   i, j;
-    int   num_errs = 0;		/* number of errors so far */
+    int   num_errs = 0; /* number of errors so far */
 
     /* Initialize data for the dataset */
     for (j = 0; j < Y_LENGTH; j++) {
@@ -537,38 +539,44 @@ static intn test_extend_SDSs(int32 fid)
             data[j][i] = (i + j) + 1;
     }
 
+    for (j = 0; j < Y_LENGTH; j++) {
+        fdata[j] = -1.0F;
+    }
+
     /* Create a 2x2 dataset called "EmptyDataset" */
     dimsize[0] = SD_UNLIMITED;
     dimsize[1] = X_LENGTH;
-    sds_id = SDcreate(fid, "AppendableDataset 1", DFNT_INT32, 2, dimsize);
+    sds_id     = SDcreate(fid, "AppendableDataset 1", DFNT_INT32, 2, dimsize);
     CHECK(sds_id, FAIL, "test_extend_SDSs: SDcreate 'AppendableDataset 1'");
 
     /* Write the stored data to the dataset */
     start[0] = start[1] = 0;
-    edges[0] = Y_LENGTH;
-    edges[1] = X_LENGTH;
-    status = SDwritedata(sds_id, start, NULL, edges, (VOIDP)data);
+    edges[0]            = Y_LENGTH;
+    edges[1]            = X_LENGTH;
+    status              = SDwritedata(sds_id, start, NULL, edges, (void *)data);
     CHECK(sds_id, FAIL, "test_extend_SDSs: SDwritedata");
 
     /* Check data. */
-    HDmemset(&output, 0, sizeof(output));
-    status = SDreaddata(sds_id, start, NULL, edges, (VOIDP)output);
+    memset(&output, 0, sizeof(output));
+    status = SDreaddata(sds_id, start, NULL, edges, (void *)output);
     CHECK(sds_id, FAIL, "test_extend_SDSs: SDreaddata");
     /* Initialize data for the dataset */
     for (j = 0; j < Y_LENGTH; j++)
         for (i = 0; i < X_LENGTH; i++)
-	    if (output[j][i] != data[j][i])
-		fprintf(stderr, "Read value (%d) differs from written (%d) at [%d,%d]\n", output[j][i], data[j][i], j, i);
+            if (output[j][i] != data[j][i])
+                fprintf(stderr, "Read value (%d) differs from written (%d) at [%d,%d]\n", output[j][i],
+                        data[j][i], j, i);
 
     /* Close this SDS */
     status = SDendaccess(sds_id);
     CHECK(status, FAIL, "test_extend_SDSs: SDendaccess");
 
     /* Check that this SDS is empty */
-    check_datasizes(fid, "AppendableDataset 1", Y_LENGTH*X_LENGTH*SIZE_INT32, Y_LENGTH*X_LENGTH*SIZE_INT32, &num_errs);
+    check_datasizes(fid, "AppendableDataset 1", Y_LENGTH * X_LENGTH * SIZE_INT32,
+                    Y_LENGTH * X_LENGTH * SIZE_INT32, &num_errs);
 
     /* Create another dataset with 1 unlimited dimension */
-    sds_id = SDcreate(fid, "AppendableDataset 2", DFNT_FLOAT64, 1, dimsize);
+    sds_id = SDcreate(fid, "AppendableDataset 2", DFNT_FLOAT32, 1, dimsize);
     CHECK(sds_id, FAIL, "test_extend_SDSs: SDcreate 'AppendableDataset 2'");
 
     /* Define the location and size of the data to be written to the dataset */
@@ -576,7 +584,7 @@ static intn test_extend_SDSs(int32 fid)
     edges1[0] = Y_LENGTH;
 
     /* Write the stored data to the dataset */
-    status = SDwritedata(sds_id, start1, NULL, edges1, (VOIDP)fdata);
+    status = SDwritedata(sds_id, start1, NULL, edges1, (void *)fdata);
     CHECK(sds_id, FAIL, "test_extend_SDSs: SDwritedata");
 
     /* Close this SDS */
@@ -584,18 +592,19 @@ static intn test_extend_SDSs(int32 fid)
     CHECK(status, FAIL, "test_extend_SDSs: SDendaccess");
 
     /* Check the size of the data of this SDS */
-    check_datasizes(fid, "AppendableDataset 2", Y_LENGTH*SIZE_FLOAT64, Y_LENGTH*SIZE_FLOAT64, &num_errs);
+    check_datasizes(fid, "AppendableDataset 2", Y_LENGTH * SIZE_FLOAT32, Y_LENGTH * SIZE_FLOAT32, &num_errs);
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
 } /* test_extend_SDSs */
 
 /* Test driver for testing the API SDgetdatasize. */
-extern int test_datasizes()
+extern int
+test_datasizes()
 {
-    int32 fid;
-    intn status;
-    int num_errs = 0;
+    int32 fid      = -1;
+    intn  status   = -1;
+    int   num_errs = 0;
 
     /* Output message about test being performed */
     TESTING("getting data size of special data (tdatasizes.c)");
@@ -621,7 +630,8 @@ extern int test_datasizes()
     status = SDend(fid);
     CHECK(status, FAIL, "test_datasizes: SDend");
 
-    if (num_errs == 0) PASSED();
+    if (num_errs == 0)
+        PASSED();
     return num_errs;
 }
 
