@@ -11,23 +11,23 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: tfile.c 5218 2009-08-29 04:21:49Z bmribler $ */
-
 #include "mfhdf.h"
 
 #ifdef HDF
 
 #include "hdftest.h"
+#include "local_nc.h"
 
 /********************************************************************
    Name: test_file_inuse() - tests preventing of an in-use file being
                 removed at cleanup time.
+                (bugzilla #376)
 
    Description:
     Sometime, when an error occurs, the cleanup process attempts to
     remove a file, which might still be in use (part of bugzilla #376.)
     The routine test_file_inuse is to test the fix that provides the
-    underlaying call to HPisfile_in_use, which should successfully
+    underlying call to HPisfile_in_use, which should successfully
     determines whether a file is still in use before an attempt to remove.
 
     The main contents include:
@@ -46,74 +46,80 @@
    Return value:
     The number of errors occurred in this routine.
 
-   BMR - Jun 22, 2005
 *********************************************************************/
 
-#define FILE_NAME     "bug376.hdf"    /* data file to test */
-#define DIM0 10
+#define FILE_NAME "bug376.hdf" /* data file to test */
+#define DIM0      10
 
 static intn
 test_file_inuse()
 {
-    int32 file_id, sd_id[5], sds_id[5];
-    intn statusn;
-    int32 dims[1], start[1], edges[1], rank;
-    int16 array_data[DIM0];
-    char* names[5] = {"data1", "data2", "data3", "data4", "data5"};
-    intn i, j;
-    intn      num_errs = 0;     /* number of errors so far */
+    int32       file_id, sd_id[5], sds_id[5];
+    intn        statusn;
+    int32       dims[1], start[1], edges[1], rank;
+    int16       array_data[DIM0];
+    const char *names[5] = {"data1", "data2", "data3", "data4", "data5"};
+    intn        i, j;
+    intn        num_errs = 0; /* number of errors so far */
 
-    for (i=0; i<5; i++)
-    {
+    for (i = 0; i < 5; i++) {
         /* Create and open the file and initiate the SD interface. */
         sd_id[i] = SDstart(FILE_NAME, DFACC_CREATE);
         if (i == 0) {
-            CHECK(sd_id[i], FAIL, "SDstart"); } /* 1st SDstart must pass */
+            CHECK(sd_id[i], FAIL, "SDstart");
+        } /* 1st SDstart must pass */
         else {
-            VERIFY(sd_id[i], FAIL, "SDstart"); }
+            VERIFY(sd_id[i], FAIL, "SDstart");
+        }
         /* subsequent SDstart should fail, which causes the following calls
         to fail as well */
 
         /* Define the rank and dimensions of the data sets to be created. */
-        rank = 1;
-        dims[0] = DIM0;
+        rank     = 1;
+        dims[0]  = DIM0;
         start[0] = 0;
         edges[0] = DIM0;
 
         /* Create the array data set. */
         sds_id[i] = SDcreate(sd_id[i], names[i], DFNT_INT16, rank, dims);
         if (i == 0) {
-            CHECK(sds_id[i], FAIL, "SDcreate"); } /* 1st SDcreate must pass */
+            CHECK(sds_id[i], FAIL, "SDcreate");
+        } /* 1st SDcreate must pass */
         else
             VERIFY(sds_id[i], FAIL, "SDcreate");
 
         /* Fill the stored-data array with values. */
         for (j = 0; j < DIM0; j++) {
-            array_data[j] = (i + 1)*(j + 1);
+            /* Max values: i = 5, j = DIM0 (10), so the largest value
+             * stored is 6 * 11 = 66
+             */
+            array_data[j] = (int16)((i + 1) * (j + 1));
         }
 
         /* Write data to the data set */
-        statusn = SDwritedata(sds_id[i], start, NULL, edges, (VOIDP)array_data);
+        statusn = SDwritedata(sds_id[i], start, NULL, edges, (void *)array_data);
         if (i == 0) {
-            CHECK(statusn, FAIL, "SDwritedata"); } /* 1st SDwritedata must pass */
+            CHECK(statusn, FAIL, "SDwritedata");
+        } /* 1st SDwritedata must pass */
         else
             VERIFY(statusn, FAIL, "SDwritedata");
 
         /* Terminate access to the data sets. */
         statusn = SDendaccess(sds_id[i]);
         if (i == 0) {
-            CHECK(statusn, FAIL, "SDendaccess"); } /* 1st SDendaccess must pass */
+            CHECK(statusn, FAIL, "SDendaccess");
+        } /* 1st SDendaccess must pass */
         else
             VERIFY(statusn, FAIL, "SDendaccess");
 
     } /* for i */
 
-    for (i=0; i<5; i++)
-    {
+    for (i = 0; i < 5; i++) {
         /* Terminate access to the SD interface and close the file. */
-        statusn = SDend (sd_id[i]);
+        statusn = SDend(sd_id[i]);
         if (i == 0) {
-            CHECK(statusn, FAIL, "SDend"); } /* 1st SDend must pass */
+            CHECK(statusn, FAIL, "SDend");
+        } /* 1st SDend must pass */
         else
             VERIFY(statusn, FAIL, "SDend");
     }
@@ -122,16 +128,17 @@ test_file_inuse()
     file_id = SDstart(FILE_NAME, DFACC_RDWR);
     CHECK(file_id, FAIL, "SDstart");
 
-    statusn = SDend (file_id);
+    statusn = SDend(file_id);
     CHECK(statusn, FAIL, "SDend");
 
     return num_errs;
-}   /* test_file_inuse */
+} /* test_file_inuse */
 
 /********************************************************************
    Name: test_max_open_files() - tests the new API SDreset_maxopenfiles,
                 SDget_maxopenfiles, SDget_numopenfiles,
                 and SDgetfilename.
+                (bugzilla #396 and #440)
 
    Description:
     There were multiple requests from the users to increase the maximum
@@ -164,24 +171,23 @@ test_file_inuse()
    Return value:
     The number of errors occurred in this routine.
 
-   BMR - Oct 14, 2005
 *********************************************************************/
 
 #define NUM_FILES_LOW 35
 #define NUM_FILES_HI  1024
 
-static int test_max_open_files()
+static int
+test_max_open_files()
 {
-    int32 fids[NUM_FILES_HI];        /* holds IDs of opened files */
-    char  filename[NUM_FILES_HI][10];    /* holds generated file names */
-    char  readfname[H4_MAX_NC_NAME];    /* file name retrieved from file id */
-    intn  index, status,
-    curr_max,     /* curr maximum number of open files allowed in HDF */
-    sys_limit,     /* maximum number of open files allowed by system */
-    curr_max_bk,  /* back up of curr_max */
-    curr_opened,    /* number of files currently being opened */
-    temp_limit,    /* temp var - num of files to be opened in this test */
-    num_errs = 0;    /* number of errors so far */
+    int32 fids[NUM_FILES_HI];         /* holds IDs of opened files */
+    char  filename[NUM_FILES_HI][10]; /* holds generated file names */
+    char  readfname[H4_MAX_NC_NAME];  /* file name retrieved from file id */
+    intn  index, status, curr_max,    /* curr maximum number of open files allowed in HDF */
+        sys_limit,                    /* maximum number of open files allowed by system */
+        curr_max_bk,                  /* back up of curr_max */
+        curr_opened,                  /* number of files currently being opened */
+        temp_limit,                   /* temp var - num of files to be opened in this test */
+        num_errs = 0;                 /* number of errors so far */
 
     /* Get the current max and system limit */
     status = SDget_maxopenfiles(&curr_max, &sys_limit);
@@ -194,8 +200,7 @@ static int test_max_open_files()
 
     /* Try to create more files than the default max (currently, 32) and
        all should succeed */
-    for (index=0; index < NUM_FILES_LOW; index++)
-    {
+    for (index = 0; index < NUM_FILES_LOW; index++) {
         /* Create a file */
         sprintf(filename[index], "file%i", index);
         fids[index] = SDstart(filename[index], DFACC_CREATE);
@@ -214,7 +219,7 @@ static int test_max_open_files()
     status = SDend(fids[25]);
     CHECK(status, FAIL, "test_maxopenfiles: SDend");
     curr_opened = SDget_numopenfiles();
-    VERIFY(curr_opened, NUM_FILES_LOW-3, "test_maxopenfiles: SDget_numopenfiles");
+    VERIFY(curr_opened, NUM_FILES_LOW - 3, "test_maxopenfiles: SDget_numopenfiles");
 
     /* Get the current max and system limit */
     status = SDget_maxopenfiles(&curr_max, &sys_limit);
@@ -238,21 +243,20 @@ static int test_max_open_files()
     /* Reset current max to a value that is smaller than the current
        number of opened files; it shouldn't reset */
     curr_max_bk = curr_max;
-    curr_max = SDreset_maxopenfiles(curr_opened-1);
+    curr_max    = SDreset_maxopenfiles(curr_opened - 1);
     VERIFY(curr_max, curr_max_bk, "test_maxopenfiles: SDreset_maxopenfiles");
 
     /* Reset current max again to a value that is smaller than the
        current max but larger than the current number of opened files,
        that should work for there is no information loss */
-    curr_max = SDreset_maxopenfiles(curr_opened+3);
-    VERIFY(curr_max, curr_opened+3, "test_maxopenfiles: SDreset_maxopenfiles");
+    curr_max = SDreset_maxopenfiles(curr_opened + 3);
+    VERIFY(curr_max, curr_opened + 3, "test_maxopenfiles: SDreset_maxopenfiles");
 
     /* Try to create more files up to the system limit or NUM_FILES_HI,
        because the arrays have max NUM_FILES_HI elements in this test */
     temp_limit = sys_limit / 2;
     temp_limit = temp_limit > NUM_FILES_HI ? NUM_FILES_HI : temp_limit;
-    for (index=NUM_FILES_LOW; index < temp_limit; index++)
-    {
+    for (index = NUM_FILES_LOW; index < temp_limit; index++) {
         /* Create a file */
         sprintf(filename[index], "file%i", index);
         fids[index] = SDstart(filename[index], DFACC_CREATE);
@@ -264,15 +268,14 @@ static int test_max_open_files()
             temp_limit = index;
 
         /* only CHECK returned value from SDstart if the failure wasn't
-           because of "too many open files" -BMR 2006/11/01 */
+           because of "too many open files" */
         else
             CHECK(fids[index], FAIL, "test_maxopenfiles: SDstart");
     }
 
     /* Close all the files, then try opening all again to verify their
        names, this is to test bugzilla 440 */
-    for (index=0; index < temp_limit; index++)
-    {
+    for (index = 0; index < temp_limit; index++) {
         status = SDend(fids[index]);
         CHECK(status, FAIL, "test_maxopenfiles: SDend");
 
@@ -281,21 +284,19 @@ static int test_max_open_files()
     }
 
     /* Verify their names */
-    for (index=0; index < temp_limit; index++)
-    {
+    for (index = 0; index < temp_limit; index++) {
         status = SDgetfilename(fids[index], readfname);
         CHECK(status, FAIL, "test_maxopenfiles: SDgetfilename");
 
         /* Verify the file name retrieved against the original */
-        if (HDstrcmp(readfname, filename[index]))
-        {
-            fprintf(stderr, "SDgetfilename: incorrect file being opened - expected <%s>, retrieved <%s>\n", filename[index], readfname);
+        if (HDstrcmp(readfname, filename[index])) {
+            fprintf(stderr, "SDgetfilename: incorrect file being opened - expected <%s>, retrieved <%s>\n",
+                    filename[index], readfname);
         }
     }
 
     /* Close then remove all the files */
-    for (index=0; index < temp_limit; index++)
-    {
+    for (index = 0; index < temp_limit; index++) {
         status = SDend(fids[index]);
         CHECK(status, FAIL, "test_maxopenfiles: SDend");
         remove(filename[index]);
@@ -317,7 +318,6 @@ static int test_max_open_files()
    Return value:
     The number of errors occurred in this routine.
 
-   BMR - Jan 16, 2009
 *********************************************************************/
 
 #define NX 2
@@ -325,17 +325,17 @@ static int test_max_open_files()
 static int
 test_longfilename()
 {
-    int32 fid;                  /* file id */
-    int32 dset1;                /* dataset ids */
-    int32 dims[2];              /* variable shapes */
-    int   ii;
-    char dsname[10];
-    char filename[256];
-    intn  status = 0;           /* status returned by called functions */
-    intn  num_errs = 0;         /* number of errors so far */
+    int32 fid;     /* file id */
+    int32 dset1;   /* dataset ids */
+    int32 dims[2]; /* variable shapes */
+    char  dsname[10];
+    char  filename[256];
+    intn  status   = 0; /* status returned by called functions */
+    intn  num_errs = 0; /* number of errors so far */
 
     strcpy(dsname, "dataset 1");
-    strcpy(filename, "This file name has quite a few characters because it is used to test the fix of bugzilla 1331. It has to be at least this long to see.");
+    strcpy(filename, "This file name has quite a few characters because it is used to test the fix of "
+                     "bugzilla 1331. It has to be at least this long to see.");
 
     /* enter define mode */
     fid = SDstart(filename, DFACC_CREATE);
@@ -358,7 +358,6 @@ test_longfilename()
     return num_errs;
 }
 
-
 /********************************************************************
    Name: test_fileformat() - tests that a file format can be
                              determined (HDFFR-1519)
@@ -373,22 +372,21 @@ test_longfilename()
    Return value:
     The number of errors occurred in this routine.
 
-   BMR - Jun 06, 2016
 *********************************************************************/
 
 static int
 test_fileformat()
 {
-    int32 fid;                  /* file id */
-    intn  ishdf = 0;            /* true if file has HDF format */
-    intn  isnetcdf = 0;         /* true if file has classic netCDF format */
-    intn  isnetcdf64 = 0;       /* true if file has 64-bit netCDF format */
-    intn  num_errs = 0;         /* number of errors so far */
-    char  testfile[512] = "";
-    char *hdf_basename = "hdffile.hdf";    /* hdf file to test */
-    char *netcdf1_basename = "Roy.nc";     /* classic netCDF file to test */
-    char *netcdf2_basename = "Roy-64.nc";  /* netCDF 64-bit file to test */
-    intn  status = 0;           /* status returned by called functions */
+    int32       fid;                  /* file id */
+    intn        ishdf            = 0; /* true if file has HDF format */
+    intn        isnetcdf         = 0; /* true if file has classic netCDF format */
+    intn        isnetcdf64       = 0; /* true if file has 64-bit netCDF format */
+    intn        num_errs         = 0; /* number of errors so far */
+    char        testfile[512]    = "";
+    const char *hdf_basename     = "hdffile.hdf"; /* hdf file to test */
+    const char *netcdf1_basename = "Roy.nc";      /* classic netCDF file to test */
+    const char *netcdf2_basename = "Roy-64.nc";   /* netCDF 64-bit file to test */
+    intn        status           = 0;             /* status returned by called functions */
 
     /* Create an empty HDF file to test Hishdf. */
     fid = SDstart(hdf_basename, DFACC_CREATE);
@@ -429,33 +427,30 @@ test_fileformat()
     return num_errs;
 }
 
-
 /* Test driver for testing miscellaneous file related APIs. */
 extern int
 test_files()
 {
-    intn num_errs = 0;         /* number of errors */
+    intn num_errs = 0; /* number of errors */
 
     /* Output message about test being performed */
     TESTING("miscellaneous file related functions (tfile.c)");
 
-    /* test that an in-use file is not removed in certain failure
-       cleanup. 06/21/05 - bugzilla 376 - BMR */
+    /* Test that an in-use file is not removed in certain failure cleanup. */
     num_errs = num_errs + test_file_inuse();
 
-    /* test APIs that were added for fixing bugzilla 396 and 440.
-       09/07/05 - BMR */
+    /* Test handling of number of open files */
     num_errs = num_errs + test_max_open_files();
 
-    /* test the fix of bugzzila 1331. 01/16/09 - BMR */
+    /* Test file with very long name */
     num_errs = num_errs + test_longfilename();
 
-    /* test the fix of JIRA HDFFR-1519. 06/06/16 - BMR */
+    /* Test determining of file format */
     num_errs = num_errs + test_fileformat();
 
-    if (num_errs == 0) PASSED();
+    if (num_errs == 0)
+        PASSED();
     return num_errs;
 }
 
 #endif /* HDF */
-
