@@ -23,7 +23,7 @@
  *	  test_nonSDAPI_ids - tests SDidtype on non SD API ids and invalid id
  *	  test_vdatavgroups - tests Vgetvgroups and VSgetvdatas
  *	  test_vgisinternal - tests Vgisinternal
-****************************************************************************/
+ ****************************************************************************/
 
 #include "mfhdf.h"
 
@@ -31,10 +31,10 @@
 
 #include "hdftest.h"
 
-#define IDTYPE_FILE     "idtypes.hdf"	/* data file to test ID types */
-#define X_LENGTH      10
-#define Y_LENGTH      10
-#define RANK          2
+#define IDTYPE_FILE "idtypes.hdf" /* data file to test ID types */
+#define X_LENGTH    10
+#define Y_LENGTH    10
+#define RANK        2
 
 /*
  Tests SDidtype on SD API ids: sd, sds, dim ids
@@ -42,11 +42,11 @@
 static intn
 test_SDAPI_ids()
 {
-    int32     fid, dset1, dset2, dim_id;
-    int32     dimsize[RANK];
+    int32        fid, dset1, dset2, dim_id;
+    int32        dimsize[RANK];
     hdf_idtype_t id_type;
-    intn      status;
-    intn      num_errs = 0;         /* number of errors so far */
+    intn         status;
+    intn         num_errs = 0; /* number of errors so far */
 
     /* Create a file */
     fid = SDstart(IDTYPE_FILE, DFACC_CREATE);
@@ -55,7 +55,7 @@ test_SDAPI_ids()
     /* Create an X_LENGTH by Y_LENGTH dataset, called DataSet_1 */
     dimsize[0] = X_LENGTH;
     dimsize[1] = Y_LENGTH;
-    dset1 = SDcreate(fid, "DataSet_1", DFNT_INT32, RANK, dimsize);
+    dset1      = SDcreate(fid, "DataSet_1", DFNT_INT32, RANK, dimsize);
     CHECK(dset1, FAIL, "SDcreate");
 
     /* Create another X_LENGTH by Y_LENGTH dataset, called DataSet_2 */
@@ -115,20 +115,20 @@ test_SDAPI_ids()
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
-}   /* test_SDAPI_ids */
+} /* test_SDAPI_ids */
 
 /*
  Tests SDidtype on non SD API ids and invalid id.
 */
 static intn
-test_nonSDAPI_ids ()
+test_nonSDAPI_ids()
 {
-    int32     fid, gr_id, vdata_id, ri_id;
-    int32     vdata_ref;
-    intn      status;
-    int32     dims[2]={4,5};    /* dimensions for the empty image */
+    int32        fid, gr_id, vdata_id, ri_id;
+    int32        vdata_ref;
+    intn         status;
+    int32        dims[2] = {4, 5}; /* dimensions for the empty image */
     hdf_idtype_t id_type;
-    intn      num_errs = 0;     /* number of errors so far */
+    intn         num_errs = 0; /* number of errors so far */
 
     /* Open the HDF file */
     fid = Hopen(IDTYPE_FILE, DFACC_RDWR, 0);
@@ -191,8 +191,7 @@ test_nonSDAPI_ids ()
     CHECK(gr_id, FAIL, "GRstart");
 
     /* Create an empty image with default fill value */
-    ri_id = GRcreate(gr_id, "Empty Image", 3, DFNT_FLOAT32, 
-		MFGR_INTERLACE_PIXEL, dims);
+    ri_id = GRcreate(gr_id, "Empty Image", 3, DFNT_FLOAT32, MFGR_INTERLACE_PIXEL, dims);
     CHECK(ri_id, FAIL, "GRcreate");
 
     /* Test SDidtype on the GR raster image id */
@@ -211,8 +210,7 @@ test_nonSDAPI_ids ()
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
-}   /* test_nonSDAPI_ids */
-
+} /* test_nonSDAPI_ids */
 
 /****************************************************************************
  * test_vdatavgroups - tests the API functions Vgetvgroups and VSgetvdatas.
@@ -232,34 +230,34 @@ test_nonSDAPI_ids ()
  *   - Reopen the file using V API
  *   - Verify that Vgetvgroups and VSgetvdatas return only the vgroups and
  *     vdatas that were created by the application.
- * Mar 4, 2011 -BMR
-****************************************************************************/
+ *
+ ****************************************************************************/
 /* data file to test getting vgs/vds from an SD file */
 #define VVS_FILE   "tvdatasvgroups_SD.hdf"
-#define ATTR1_NAME  "Valid_range 1"
-#define ATTR2_NAME  "Unit"
-#define X_LENGTH    10
-#define Y_LENGTH    10
-#define RANK        2
-#define NUM_VGS     3
-#define NUM_VDS     1
+#define ATTR1_NAME "Valid_range 1"
+#define ATTR2_NAME "Unit"
+#define X_LENGTH   10
+#define Y_LENGTH   10
+#define RANK       2
+#define NUM_VGS    3
+#define NUM_VDS    1
 
 static intn
 test_vdatavgroups()
 {
-    int32   fid, dset1, dset2, dset3, dimid, vgroup_id, vdata_id;
-    int32   num_allvgroups, num_allvdatas;
-    intn    num_vgroups, num_vdatas;
-    int32   dimsize[RANK];
-    float32 att1_values[2] = {2., 10.};
-    char8   att2_values[]  = "Seconds";
-    uint16 *refarray=NULL;
-    uint16  name_len=0;
-    intn    ii, status;
-    char   *vg_name=NULL, vd_name[10];
-    const char   *check_vg_names[3] = {"Vgroup_1", "Vgroup_2", "Vgroup_3"};
-    const char   *check_vd_names[1] = {"Vdata_1"};
-    intn    num_errs = 0;     /* number of errors so far */
+    int32       fid, dset1, dset2, dset3, dimid, vgroup_id, vdata_id;
+    int32       num_allvdatas;
+    intn        num_vgroups, num_vdatas;
+    int32       dimsize[RANK];
+    float32     att1_values[2] = {2., 10.};
+    char8       att2_values[]  = "Seconds";
+    uint16     *refarray       = NULL;
+    uint16      name_len       = 0;
+    intn        ii, status;
+    char       *vg_name           = NULL, vd_name[10];
+    const char *check_vg_names[3] = {"Vgroup_1", "Vgroup_2", "Vgroup_3"};
+    const char *check_vd_names[1] = {"Vdata_1"};
+    intn        num_errs          = 0; /* number of errors so far */
 
     /* Create a file */
     fid = SDstart(VVS_FILE, DFACC_CREATE);
@@ -268,13 +266,13 @@ test_vdatavgroups()
     /* Create an X_LENGTH by Y_LENGTH dataset, called DataSet_1 */
     dimsize[0] = X_LENGTH;
     dimsize[1] = Y_LENGTH;
-    dset1 = SDcreate(fid, "DataSet_1", DFNT_INT32, RANK, dimsize);
+    dset1      = SDcreate(fid, "DataSet_1", DFNT_INT32, RANK, dimsize);
     CHECK(dset1, FAIL, "SDcreate");
 
     /* Set attribute to first dimension of first data set */
-    dimid = SDgetdimid (dset1, 0);
+    dimid = SDgetdimid(dset1, 0);
     CHECK(dimid, FAIL, "SDgetdimid");
-    status = SDsetattr (dimid, ATTR1_NAME, DFNT_FLOAT32, 2, (VOIDP)att1_values);
+    status = SDsetattr(dimid, ATTR1_NAME, DFNT_FLOAT32, 2, (void *)att1_values);
     CHECK(status, FAIL, "SDsetattr");
 
     /* Create another X_LENGTH by Y_LENGTH dataset, called DataSet_2 */
@@ -282,9 +280,9 @@ test_vdatavgroups()
     CHECK(dset2, FAIL, "SDcreate");
 
     /* Set attribute to second dimension of second data set */
-    dimid = SDgetdimid (dset2, 1);
+    dimid = SDgetdimid(dset2, 1);
     CHECK(dimid, FAIL, "SDgetdimid");
-    status = SDsetattr (dimid, ATTR2_NAME, DFNT_CHAR, 7, (VOIDP)att2_values);
+    status = SDsetattr(dimid, ATTR2_NAME, DFNT_CHAR, 7, (void *)att2_values);
     CHECK(status, FAIL, "SDsetattr");
 
     /* Create another X_LENGTH by Y_LENGTH dataset, called DataSet_2 */
@@ -311,7 +309,7 @@ test_vdatavgroups()
 
     /*   num_allvgroups = Hnumber(fid, DFTAG_VG);
     CHECK(num_allvgroups, FAIL, "Hnumber");
-    keep for debugging only */ 
+    keep for debugging only */
 
     /* Get the number of user-created vgroups */
     num_vgroups = Vgetvgroups(fid, 0, 0, NULL);
@@ -321,7 +319,7 @@ test_vdatavgroups()
     /* There are internally created vds because of attributes and dimensions */
     num_allvdatas = Hnumber(fid, DFTAG_VH);
     CHECK(num_allvdatas, FAIL, "Hnumber");
-    CHECK(num_allvdatas, 0, "Hnumber");  /* so num_allvdatas shouldn't be 0 */
+    CHECK(num_allvdatas, 0, "Hnumber"); /* so num_allvdatas shouldn't be 0 */
 
     /* Get the number of user-created vdatas */
     num_vdatas = VSgetvdatas(fid, 0, 0, NULL);
@@ -375,7 +373,7 @@ test_vdatavgroups()
     VERIFY(num_vgroups, NUM_VGS, "Vgetvgroups");
 
     /* Allocate sufficient memory to hold the list of user-created vg refs */
-    refarray = (uint16 *)HDmalloc(sizeof(uint16) * num_vgroups);
+    refarray = (uint16 *)malloc(sizeof(uint16) * num_vgroups);
     CHECK_ALLOC(refarray, "refarray", "test_vdatavgroups");
 
     /* Now, get the user-created vgroup refs */
@@ -384,31 +382,30 @@ test_vdatavgroups()
     VERIFY(status, num_vgroups, "Vgetvgroups");
 
     /* Verify the name of these user-created vgroups */
-    for (ii = 0; ii < num_vgroups; ii++)
-    {
-	vgroup_id = Vattach(fid, refarray[ii], "r");
-	CHECK(vgroup_id, FAIL, "Vattach");
+    for (ii = 0; ii < num_vgroups; ii++) {
+        vgroup_id = Vattach(fid, refarray[ii], "r");
+        CHECK(vgroup_id, FAIL, "Vattach");
 
-	status = Vgetnamelen(vgroup_id, &name_len);
-	CHECK(status, FAIL, "Vgetnamelen");
+        status = Vgetnamelen(vgroup_id, &name_len);
+        CHECK(status, FAIL, "Vgetnamelen");
 
-	vg_name = (char *)HDmalloc((sizeof(char) * name_len) + 1);
-	CHECK_ALLOC(vg_name, "vg_name", "test_vdatavgroups");
+        vg_name = (char *)malloc((sizeof(char) * name_len) + 1);
+        CHECK_ALLOC(vg_name, "vg_name", "test_vdatavgroups");
 
-	status = Vgetname(vgroup_id, vg_name);
-	CHECK(status, FAIL, "Vgetname");
-	VERIFY_CHAR(vg_name, check_vg_names[ii], "");
+        status = Vgetname(vgroup_id, vg_name);
+        CHECK(status, FAIL, "Vgetname");
+        VERIFY_CHAR(vg_name, check_vg_names[ii], "");
 
-	if (strncmp(vg_name, check_vg_names[ii], name_len) != 0)
-	    fprintf(stderr, "vg %d: name is %s, should be %s\n", ii, vg_name, check_vg_names[ii]);
+        if (strncmp(vg_name, check_vg_names[ii], name_len) != 0)
+            fprintf(stderr, "vg %d: name is %s, should be %s\n", ii, vg_name, check_vg_names[ii]);
 
-    /* Release resource */
-    HDfree(vg_name);
-	status = Vdetach(vgroup_id);
-	CHECK(status, FAIL, "Vdetach");
+        /* Release resource */
+        free(vg_name);
+        status = Vdetach(vgroup_id);
+        CHECK(status, FAIL, "Vdetach");
     }
     /* Release resource */
-    HDfree(refarray);
+    free(refarray);
 
     /* Get the number of user-created vdatas */
     num_vdatas = VSgetvdatas(fid, 0, 0, NULL);
@@ -416,7 +413,7 @@ test_vdatavgroups()
     VERIFY(num_vdatas, NUM_VDS, "VSgetvdatas");
 
     /* Allocate sufficient memory to hold the list of user-created vd refs */
-    refarray = (uint16 *)HDmalloc(sizeof(uint16) * num_vdatas);
+    refarray = (uint16 *)malloc(sizeof(uint16) * num_vdatas);
     CHECK_ALLOC(refarray, "refarray", "test_vdatavgroups");
 
     /* Now, get the user-created vdata refs */
@@ -425,23 +422,22 @@ test_vdatavgroups()
     VERIFY(status, num_vdatas, "VSgetvdatas");
 
     /* Verify the name of these user-created vdatas */
-    for (ii = 0; ii < num_vdatas; ii++)
-    {
-	vdata_id = VSattach(fid, refarray[ii], "r");
-	CHECK(vdata_id, FAIL, "VSattach");
+    for (ii = 0; ii < num_vdatas; ii++) {
+        vdata_id = VSattach(fid, refarray[ii], "r");
+        CHECK(vdata_id, FAIL, "VSattach");
 
-	status = VSgetname(vdata_id, vd_name);
-	CHECK(status, FAIL, "VSgetname");
+        status = VSgetname(vdata_id, vd_name);
+        CHECK(status, FAIL, "VSgetname");
 
-	VERIFY_CHAR(vd_name, check_vd_names[ii], "");
+        VERIFY_CHAR(vd_name, check_vd_names[ii], "");
 
-	if (strncmp(vd_name, check_vd_names[ii], name_len) != 0)
-	    fprintf(stderr, "vd %d: name is %s, should be %s\n", ii, vd_name, check_vd_names[ii]);
-	status = VSdetach(vdata_id);
-	CHECK(status, FAIL, "VSdetach");
+        if (strncmp(vd_name, check_vd_names[ii], name_len) != 0)
+            fprintf(stderr, "vd %d: name is %s, should be %s\n", ii, vd_name, check_vd_names[ii]);
+        status = VSdetach(vdata_id);
+        CHECK(status, FAIL, "VSdetach");
     }
     /* Release resource */
-    HDfree(refarray);
+    free(refarray);
 
     /* Terminate access to the Vxxx interface and close the file */
     status = Vend(fid);
@@ -451,31 +447,29 @@ test_vdatavgroups()
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
-}   /* test_vdatavgroups */
-
+} /* test_vdatavgroups */
 
 /****************************************************************************
  * test_vgisinternal - tests the API function Vgisinternal
  *   - Use the existing files created by test_vdatavgroups
  *   - Get the number of vgroups in the file
  *   - For each vgroup, verify that it is internal or not
- * Jan 6, 2012 -BMR
-****************************************************************************/
+ *
+ ****************************************************************************/
 
-#define VVS_FILE   "tvdatasvgroups_SD.hdf"
-#define GR_FILE    "grtdfui83.hdf"
+#define VVS_FILE "tvdatasvgroups_SD.hdf"
+#define GR_FILE  "grtdfui83.hdf"
 static intn
 test_vgisinternal()
 {
-    int32   fid, vgroup_id;
-    intn    is_internal = FALSE;
-    int32   vref = -1;
-    intn    ii, status;
-    char    internal_array1[20] = {TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE,
-                         TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE};
-    char    internal_array2[9] = {TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE,
-			 TRUE, TRUE};
-    intn    num_errs = 0;     /* number of errors so far */
+    int32 fid, vgroup_id;
+    intn  is_internal = FALSE;
+    int32 vref        = -1;
+    intn  ii, status;
+    char  internal_array1[20] = {TRUE, TRUE, TRUE, TRUE, TRUE,  TRUE,  TRUE, TRUE,
+                                TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, FALSE};
+    char  internal_array2[9]  = {TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE};
+    intn  num_errs            = 0; /* number of errors so far */
 
     /* Open the HDF file and initialize the V interface */
     fid = Hopen(VVS_FILE, DFACC_READ, 0);
@@ -484,20 +478,19 @@ test_vgisinternal()
     CHECK(status, FAIL, "Vstart");
 
     ii = 0;
-    while ((vref = Vgetid(fid, vref)) != FAIL)
-    {     /* until no more vgroups */
-	vgroup_id = Vattach(fid, vref, "r"); /* attach to vgroup */
+    while ((vref = Vgetid(fid, vref)) != FAIL) { /* until no more vgroups */
+        vgroup_id = Vattach(fid, vref, "r");     /* attach to vgroup */
 
-	/* Test that the current vgroup is or is not internal as specified in
-	   the array */
-	is_internal = Vgisinternal(vgroup_id);
-	CHECK(is_internal, FAIL, "Vgisinternal");
-	VERIFY(is_internal, internal_array1[ii], "Vgisinternal");
+        /* Test that the current vgroup is or is not internal as specified in
+           the array */
+        is_internal = Vgisinternal(vgroup_id);
+        CHECK(is_internal, FAIL, "Vgisinternal");
+        VERIFY(is_internal, internal_array1[ii], "Vgisinternal");
 
-	status = Vdetach(vgroup_id);
-	CHECK(status, FAIL, "Vdetach");
+        status = Vdetach(vgroup_id);
+        CHECK(status, FAIL, "Vdetach");
 
-	ii++;
+        ii++;
     }
 
     /* Terminate access to the V interface and close the file */
@@ -515,20 +508,19 @@ test_vgisinternal()
     CHECK(status, FAIL, "Vstart");
 
     ii = 0;
-    while ((vref = Vgetid(fid, vref)) != FAIL)
-    {     /* until no more vgroups */
-	vgroup_id = Vattach(fid, vref, "r"); /* attach to vgroup */
+    while ((vref = Vgetid(fid, vref)) != FAIL) { /* until no more vgroups */
+        vgroup_id = Vattach(fid, vref, "r");     /* attach to vgroup */
 
-	/* Test that the current vgroup is or is not internal as specified in
-	   the array */
-	is_internal = Vgisinternal(vgroup_id);
-	CHECK(is_internal, FAIL, "Vgisinternal");
-  	VERIFY(is_internal, internal_array2[ii], "Vgisinternal");
+        /* Test that the current vgroup is or is not internal as specified in
+           the array */
+        is_internal = Vgisinternal(vgroup_id);
+        CHECK(is_internal, FAIL, "Vgisinternal");
+        VERIFY(is_internal, internal_array2[ii], "Vgisinternal");
 
-	status = Vdetach(vgroup_id);
-	CHECK(status, FAIL, "Vdetach");
+        status = Vdetach(vgroup_id);
+        CHECK(status, FAIL, "Vdetach");
 
-	ii++; /* increment vgroup index */
+        ii++; /* increment vgroup index */
     }
 
     /* Terminate access to the V interface and close the file */
@@ -539,15 +531,14 @@ test_vgisinternal()
 
     /* Return the number of errors that's been kept track of so far */
     return num_errs;
-}   /* test_vgisinternal */
+} /* test_vgisinternal */
 
-
-/* Test driver for testing the API functions SDidtype, Vgetvgroups, 
+/* Test driver for testing the API functions SDidtype, Vgetvgroups,
    VSgetvdatas, and Vgisinternal. */
 extern int
 test_mixed_apis()
 {
-    intn num_errs = 0;         /* number of errors */
+    intn num_errs = 0; /* number of errors */
 
     /* Output message about test being performed */
     TESTING("a mix of SD, V, and VS functions (tmixed_apis.c)");
@@ -561,7 +552,8 @@ test_mixed_apis()
     /* Test Vgisinternal */
     num_errs = num_errs + test_vgisinternal();
 
-    if (num_errs == 0) PASSED();
+    if (num_errs == 0)
+        PASSED();
     return num_errs;
 }
 
